@@ -1288,9 +1288,6 @@ checkDisplayStatus(struct display *d)
 {
     if ((d->displayType & d_origin) == dFromFile && !d->stillThere)
         stopDisplay(d);
-    else if ((d->displayType & d_lifetime) == dReserve &&
-             d->status == running && d->userSess < 0 && !d->idleTimeout)
-        rStopDisplay(d, DS_RESERVE);
     else if (d->status == notRunning)
         if (loadDisplayResources(d) < 0) {
             logError("Unable to read configuration for display %s; "
@@ -1422,8 +1419,8 @@ startDisplay(struct display *d)
              * servers which read auth file only on reset instead of
              * at first connection)
              */
-            if (d->serverPid != -1 && d->resetForAuth && d->resetSignal)
-                kill(d->serverPid, d->resetSignal);
+            if (d->serverPid != -1 && d->resetForAuth)
+                kill(d->serverPid, SIGHUP);
         }
         if (d->serverPid == -1) {
             d->serverStatus = awaiting;
@@ -1464,6 +1461,8 @@ startDisplayP2(struct display *d)
         waitForServer(d);
         if ((d->displayType & d_location) == dLocal) {
             gSet(&mstrtalk);
+            if (Setjmp(mstrtalk.errjmp))
+                exit(EX_UNMANAGE_DPY);
             gSendInt(D_XConnOk);
         }
         manageSession();
@@ -1496,12 +1495,11 @@ rStopDisplay(struct display *d, int endState)
 {
     debug("stopping display %s to state %d\n", d->name, endState);
     abortStartServer(d);
-    d->idleTimeout = 0;
     if (d->serverPid != -1 || d->pid != -1) {
         if (d->pid != -1)
             terminateProcess(d->pid, SIGTERM);
         if (d->serverPid != -1)
-            terminateProcess(d->serverPid, d->termSignal);
+            terminateProcess(d->serverPid, SIGTERM);
         d->status = zombie;
         d->zstatus = endState & DS_MASK;
         debug(" zombiefied\n");
@@ -1516,6 +1514,7 @@ rStopDisplay(struct display *d, int endState)
 #endif
     } else if (endState == DS_RESERVE) {
         d->status = reserve;
+        d->hstent->lastExit = 0;
 #ifdef XDMCP
     } else if (endState == DS_REMOTE) {
         startRemoteLogin(d);
@@ -1589,7 +1588,7 @@ exitDisplay(struct display *d, int endState, int serverCmd, int goodExit)
                 (serverCmd != XS_KEEP || d->terminateServer))
             {
                 debug("killing X server for %s\n", d->name);
-                terminateProcess(d->serverPid, d->termSignal);
+                terminateProcess(d->serverPid, SIGTERM);
                 d->status = phoenix;
             } else {
                 d->status = notRunning;
