@@ -25,7 +25,6 @@
 
 //KDE
 #include <KDebug>
-
 KcmTreeItem::KcmTreeItem(const KService::Ptr module, KcmTreeItem *parent) : m_parent(parent), m_module(module), 
   m_moduleInfo(new KCModuleInfo(m_module))
 {
@@ -38,7 +37,7 @@ KcmTreeItem::KcmTreeItem() : m_parent(NULL), m_moduleInfo(new KCModuleInfo())
 KcmTreeItem::~KcmTreeItem()
 {
   qDeleteAll(m_children);
-  delete m_parent;
+  delete m_moduleInfo;
 }
 
 void KcmTreeItem::addChild(KcmTreeItem *child) 
@@ -46,7 +45,7 @@ void KcmTreeItem::addChild(KcmTreeItem *child)
   m_children.append(child);
 }
 
-KcmTreeItem *KcmTreeItem::child(int row)
+KcmTreeItem *KcmTreeItem::child(const int row)
 {
   if(childCount() > row) return m_children.value(row);
   return NULL;
@@ -88,12 +87,12 @@ int KcmTreeItem::indexOf(KcmTreeItem *item)
   return 0;
 }
 
-QString KcmTreeItem::data()
+QString KcmTreeItem::data() const
 {
   return m_moduleInfo->moduleName();
 }
 
-QString KcmTreeItem::category()
+QString KcmTreeItem::category() const
 {
   return m_module->property("X-KDE-KInfoCenter-Category").toString().trimmed();
 }
@@ -103,7 +102,7 @@ KcmTreeItem::itemType KcmTreeItem::type() const
   return KCM;
 }
 
-KcmTreeItem *KcmTreeItem::containsCategory(QString category) 
+KcmTreeItem *KcmTreeItem::containsCategory(const QString& category) 
 {
   foreach(KcmTreeItem *item, m_children)
   {
@@ -125,12 +124,12 @@ KcmTreeItem *KcmTreeItem::containsCategory(QString category)
   return NULL;
 }
 
-const KCModuleInfo KcmTreeItem::kcm() const 
+KCModuleInfo KcmTreeItem::kcm() const 
 {
   return *m_moduleInfo;
 }
 
-int KcmTreeItem::weight() 
+int KcmTreeItem::weight()
 {
   return m_moduleInfo->weight();
 }
@@ -145,7 +144,7 @@ QString KcmTreeItem::whatsThis() const
   return m_moduleInfo->comment();
 }
 
-bool KcmTreeItem::childrenRegExp(QRegExp pattern)
+bool KcmTreeItem::childrenRegExp(const QRegExp& pattern)
 {
   foreach(KcmTreeItem *item, m_children)
   {
@@ -157,7 +156,7 @@ bool KcmTreeItem::childrenRegExp(QRegExp pattern)
   return false;
 }
 
-QStringList KcmTreeItem::keywords()
+QStringList KcmTreeItem::keywords() const
 {
   if(m_moduleInfo->keywords().isEmpty()) return QStringList(data());
   return m_moduleInfo->keywords();
