@@ -66,8 +66,6 @@ class SidePanel : public QTreeView
     */
     QModelIndex mapToProxySource(const QModelIndex&);
 
-    // void filterSideMenu(QString);
-
     /**
     * Get all the treeview items keywords
     */
@@ -78,21 +76,21 @@ class SidePanel : public QTreeView
      */
     void toggleExpand(const KcmTreeItem *);
     
-  signals:
+  Q_SIGNALS:
   
     /**
     * Emitted when menu item is clicked
     */
     void activated(const KcmTreeItem *);
 
-  private slots:
+  private Q_SLOTS:
 
     /**
     * Triggered when treeview item is clicked
     */
     void activatedSlot(const QModelIndex &index);
 
-  public slots:
+  public Q_SLOTS:
     
     /**
     * Triggered when collapseAll is selected from tree view 
