@@ -56,7 +56,7 @@
 #include "krunnersettings.h"
 #include "interfaces/default/resultscene.h"
 #include "interfaces/default/resultitem.h"
-#include "interfaces/default/krunnertabfilter.h"
+#include "interfaces/default/krunnerhistorycombobox.h"
 #include "interfaces/default/resultsview.h"
 #include "toolbutton.h"
 
@@ -90,7 +90,7 @@ Interface::Interface(Plasma::RunnerManager *runnerManager, QWidget *parent)
     //Set up the system activity button, using the krunner global action, showing the global shortcut in the tooltip
     m_activityButton = new ToolButton(m_buttonContainer);
     KRunnerApp *krunnerApp = KRunnerApp::self();
-    QAction *showSystemActivityAction = krunnerApp->actionCollection()->action("Show System Activity");
+    QAction *showSystemActivityAction = krunnerApp->actionCollection()->action(QLatin1String( "Show System Activity" ));
     m_activityButton->setDefaultAction(showSystemActivityAction);
 
     updateSystemActivityToolTip();
@@ -116,26 +116,18 @@ Interface::Interface(Plasma::RunnerManager *runnerManager, QWidget *parent)
     m_closeButton = new ToolButton(m_buttonContainer);
     KGuiItem guiItem = KStandardGuiItem::close();
     m_closeButton->setText(guiItem.text());
-    m_closeButton->setToolTip(guiItem.text().remove('&'));
+    m_closeButton->setToolTip(guiItem.text().remove(QLatin1Char( '&' )));
     connect(m_closeButton, SIGNAL(clicked(bool)), SLOT(resetAndClose()));
     bottomLayout->addWidget(m_closeButton);
 
     m_layout->addWidget(m_buttonContainer);
 
-    m_searchTerm = new KHistoryComboBox(false, this);
-    m_searchTerm->setPalette(QApplication::palette());
-    m_searchTerm->setDuplicatesEnabled(false);
+    m_searchTerm = new KrunnerHistoryComboBox(false, this);
 
     KLineEdit *lineEdit = new KLineEdit(m_searchTerm);
     QAction *focusEdit = new QAction(this);
     focusEdit->setShortcut(Qt::Key_F6);
 
-    // in theory, the widget should detect the direction from the content
-    // but this is not available in Qt4.4/KDE 4.2, so the best default for this widget
-    // is LTR: as it's more or less a "command line interface"
-    // FIXME remove this code when KLineEdit has automatic direction detection of the "paragraph"
-    m_searchTerm->setLayoutDirection(Qt::LeftToRight);
-
     connect(focusEdit, SIGNAL(triggered(bool)), this, SLOT(searchTermSetFocus()));
     addAction(focusEdit);
 
@@ -150,7 +142,6 @@ Interface::Interface(Plasma::RunnerManager *runnerManager, QWidget *parent)
     lineEdit->setClearButtonShown(true);
     QStringList pastQueryItems = KRunnerSettings::pastQueries();
     m_searchTerm->setHistoryItems(pastQueryItems);
-    m_searchTerm->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
     m_completion->insertItems(pastQueryItems);
     bottomLayout->insertWidget(4, m_searchTerm, 10);
 
@@ -162,20 +153,17 @@ Interface::Interface(Plasma::RunnerManager *runnerManager, QWidget *parent)
     m_resultsView = new ResultsView(m_resultsScene, &m_resultData, this);
     m_layout->addWidget(m_resultsView);
 
+    connect(m_resultsScene, SIGNAL(viewableHeightChanged()), this, SLOT(fitWindow()));
     connect(m_resultsScene, SIGNAL(matchCountChanged(int)), this, SLOT(matchCountChanged(int)));
     connect(m_resultsScene, SIGNAL(itemActivated(ResultItem *)), this, SLOT(run(ResultItem *)));
 
-    connect(lineEdit, SIGNAL(textEdited(QString)), this, SLOT(queryTextEdited(QString)));
-    connect(m_searchTerm, SIGNAL(currentIndexChanged(QString)), this, SLOT(queryTextEdited(QString)));
+    connect(m_searchTerm, SIGNAL(queryTextEdited(QString)), this, SLOT(queryTextEdited(QString)));
     connect(m_searchTerm, SIGNAL(returnPressed()), this, SLOT(runDefaultResultItem()));
     connect(m_singleRunnerSearchTerm, SIGNAL(textChanged(QString)), this, SLOT(queryTextEdited(QString)));
     connect(m_singleRunnerSearchTerm, SIGNAL(returnPressed()),  this, SLOT(runDefaultResultItem()));
 
-    KrunnerTabFilter *krunnerTabFilter = new KrunnerTabFilter(m_resultsScene, lineEdit, this);
-    m_searchTerm->installEventFilter(krunnerTabFilter);
-    connect(krunnerTabFilter, SIGNAL(historyRotated(QString)), this, SLOT(queryTextEdited(QString)));
     lineEdit->installEventFilter(this);
-    m_singleRunnerSearchTerm->installEventFilter(this);
+    m_searchTerm->installEventFilter(this);
 
     themeUpdated();
     connect(Plasma::Theme::defaultTheme(), SIGNAL(themeChanged()), this, SLOT(themeUpdated()));
@@ -222,12 +210,27 @@ Interface::Interface(Plasma::RunnerManager *runnerManager, QWidget *parent)
 
 bool Interface::eventFilter(QObject *obj, QEvent *event)
 {
-    if (event->type() == QEvent::MouseButtonPress) {
+    if (obj == m_searchTerm->lineEdit() && event->type() == QEvent::MouseButtonPress) {
         if (KWindowSystem::activeWindow() != winId()) {
             // this overcomes problems with click-to-focus and being a Dock window
             KWindowSystem::forceActiveWindow(winId());
             searchTermSetFocus();
         }
+    } else if (obj == m_searchTerm && event->type() == QEvent::KeyPress) {
+        QKeyEvent *ke = static_cast<QKeyEvent *>(event);
+        // the comparision between itemText(1) and the currentText is an artifact
+        // of KHistoryComboBox: it sets the combobox to index 1 when using arrow-down
+        // through entries after having arrow-up'd through them and hitting the
+        // last item ... which one would expect to be index 0. index 1 is _also_
+        // the first item in the history at other times, however, so we need to
+        // check if index 1 is indeed the actual item or if item 1 is not the same
+        // the current text. very, very odd. but it works. - aseigo.
+        if (ke->key() == Qt::Key_Down &&
+            (m_searchTerm->currentIndex() < 1 ||
+             (m_searchTerm->currentIndex() == 1 &&
+              m_searchTerm->itemText(1) != m_searchTerm->currentText()))) {
+            m_resultsView->setFocus();
+        }
     }
 
     return KRunnerDialog::eventFilter(obj, event);
@@ -247,7 +250,7 @@ void Interface::updateSystemActivityToolTip()
 {
     /* Set the tooltip for the Show System Activity button to include the global shortcut */
     KRunnerApp *krunnerApp = KRunnerApp::self();
-    KAction *showSystemActivityAction = dynamic_cast<KAction *>(krunnerApp->actionCollection()->action("Show System Activity"));
+    KAction *showSystemActivityAction = dynamic_cast<KAction *>(krunnerApp->actionCollection()->action(QLatin1String( "Show System Activity" )));
     if (showSystemActivityAction) {
         QString shortcut = showSystemActivityAction->globalShortcut().toString();
         if (shortcut.isEmpty()) {
@@ -328,10 +331,10 @@ void Interface::searchTermSetFocus()
 void Interface::themeUpdated()
 {
     //reset the icons
-    m_helpButton->setIcon(m_iconSvg->pixmap("help"));
-    m_configButton->setIcon(m_iconSvg->pixmap("configure"));
-    m_activityButton->setIcon(m_iconSvg->pixmap("status"));
-    m_closeButton->setIcon(m_iconSvg->pixmap("close"));
+    m_helpButton->setIcon(m_iconSvg->pixmap(QLatin1String( "help" )));
+    m_configButton->setIcon(m_iconSvg->pixmap(QLatin1String( "configure" )));
+    m_activityButton->setIcon(m_iconSvg->pixmap(QLatin1String( "status" )));
+    m_closeButton->setIcon(m_iconSvg->pixmap(QLatin1String( "close" )));
 }
 
 void Interface::clearHistory()
@@ -394,15 +397,15 @@ void Interface::showHelp()
         int count = 0;
         QIcon icon(runner->icon());
         if (icon.isNull()) {
-            icon = KIcon("system-run");
+            icon = KIcon(QLatin1String( "system-run" ));
         }
 
         foreach (const Plasma::RunnerSyntax &syntax, runner->syntaxes()) {
             Plasma::QueryMatch match(0);
             match.setType(Plasma::QueryMatch::InformationalMatch);
             match.setIcon(icon);
-            match.setText(syntax.exampleQueriesWithTermDescription().join(", "));
-            match.setSubtext(syntax.description() + "\n" +
+            match.setText(syntax.exampleQueriesWithTermDescription().join(QLatin1String( ", " )));
+            match.setSubtext(syntax.description() + QLatin1Char( '\n' ) +
                              i18n("(From %1, %2)", runner->name(), runner->description()));
             match.setData(syntax.exampleQueries().first());
             matches.insert(runner->name() + QString::number(++count), match);
@@ -453,11 +456,11 @@ void Interface::run(ResultItem *item)
         if (!info.isEmpty()) {
             if (item->isQueryPrototype()) {
                 // lame way of checking to see if this is a Help Button generated match!
-                int index = info.indexOf(":q:");
+                int index = info.indexOf(QLatin1String( ":q:" ));
 
                 if (index != -1) {
                     editPos = index;
-                    info.replace(":q:", "");
+                    info.replace(QLatin1String( ":q:" ), QLatin1String( "" ));
                 }
             }
 
@@ -473,9 +476,8 @@ void Interface::run(ResultItem *item)
         return;
     }
 
-    // We need to keep a copy of the query text before calling close(),
-    // in order to add it to history later on.
-    QString currentQuery = m_searchTerm->currentText().trimmed();
+    //TODO: check if run is succesful before adding the term to history
+    m_searchTerm->addToHistory(m_searchTerm->currentText().trimmed());
 
     m_running = true;
     // must run the result first before clearing the interface
@@ -485,11 +487,6 @@ void Interface::run(ResultItem *item)
     m_resultsScene->run(item);
     m_running = false;
 
-    //TODO: check if run is succesful before adding the term to history
-    // Notice that we must add items to history after calling m_resultScene->run()
-    // otherwise the query result could be reset to QString() too early.
-    m_searchTerm->addToHistory(currentQuery);
-
     resetInterface();
 }
 
@@ -530,9 +527,14 @@ void Interface::delayedQueryLaunch()
     if (m_runnerManager->singleMode()) {
         runnerId = m_runnerManager->singleModeRunnerId();
     }
+
     if (!query.isEmpty() || m_runnerManager->singleMode()) {
         m_queryRunning = m_resultsScene->launchQuery(query, runnerId) || m_queryRunning; //lazy OR?
     }
+
+    if (!m_queryRunning && m_delayedRun) {
+        runDefaultResultItem();
+    }
 }
 
 void Interface::matchCountChanged(int count)
@@ -550,30 +552,7 @@ void Interface::matchCountChanged(int count)
     if (show) {
         //kDebug() << "showing!" << minimumSizeHint();
 
-        QSize s = m_defaultSize;
-        const int resultsHeight = m_resultsScene->viewableHeight() + 2;
-        int spacing = m_layout->spacing();
-        if (spacing < 0) {
-            // KStyles allow for variable spacing via the layoutSpacingImplementation() method;
-            // in this case m_layout->spacing() returns -1 and we should ask for the
-            // spacing by ourselves.
-            // This is quite ugly, but at least gives the right guess, so that we avoid
-            // multiple resize events
-            spacing = style()->layoutSpacing(QSizePolicy::DefaultType, QSizePolicy::DefaultType, Qt::Vertical);
-        }
-
-        //kDebug() << m_minimumHeight << resultsHeight << spacing << s.height();
-
-        if (m_minimumHeight + resultsHeight + spacing < s.height()) {
-            s.setHeight(m_minimumHeight + resultsHeight + spacing);
-            m_resultsView->setMinimumHeight(resultsHeight);
-            // The layout will activate on the next event cycle, but
-            // we need to update the minimum size now, as we are going to
-            // resize the krunner window right away.
-            m_layout->activate();
-        }
-
-        resize(s);
+        //fitWindow();
 
         if (!m_resultsView->isVisible()) {
             // Next 2 lines are a workaround to allow arrow
@@ -593,6 +572,34 @@ void Interface::matchCountChanged(int count)
     }
 }
 
+void Interface::fitWindow()
+{
+    QSize s = m_defaultSize;
+    const int resultsHeight = m_resultsScene->viewableHeight() + 2;
+    int spacing = m_layout->spacing();
+    if (spacing < 0) {
+        // KStyles allow for variable spacing via the layoutSpacingImplementation() method;
+        // in this case m_layout->spacing() returns -1 and we should ask for the
+        // spacing by ourselves.
+        // This is quite ugly, but at least gives the right guess, so that we avoid
+        // multiple resize events
+        spacing = style()->layoutSpacing(QSizePolicy::DefaultType, QSizePolicy::DefaultType, Qt::Vertical);
+    }
+
+    //kDebug() << m_minimumHeight << resultsHeight << spacing << s.height();
+
+    if (m_minimumHeight + resultsHeight + spacing < s.height()) {
+        s.setHeight(m_minimumHeight + resultsHeight + spacing);
+        m_resultsView->setMinimumHeight(resultsHeight);
+        // The layout will activate on the next event cycle, but
+        // we need to update the minimum size now, as we are going to
+        // resize the krunner window right away.
+        m_layout->activate();
+    }
+
+    resize(s);
+}
+
 void Interface::hideResultsArea()
 {
     searchTermSetFocus();
