@@ -43,6 +43,8 @@
 #include <Plasma/RunnerManager>
 #include <Plasma/AbstractRunner>
 
+#include "kworkspace/kdisplaymanager.h"
+
 #include "appadaptor.h"
 #include "kworkspace.h"
 #include "ksystemactivitydialog.h"
@@ -104,7 +106,7 @@ KActionCollection* KRunnerApp::actionCollection()
 
 void KRunnerApp::initialize()
 {
-    setWindowIcon(KIcon("system-run"));
+    setWindowIcon(KIcon(QLatin1String( "system-run" )));
 
     setQuitOnLastWindowClosed(false);
     KCrash::setFlags(KCrash::AutoRestart);
@@ -115,38 +117,31 @@ void KRunnerApp::initialize()
     m_runnerManager = new Plasma::RunnerManager;
 
     new AppAdaptor(this);
-    QDBusConnection::sessionBus().registerObject( "/App", this );
+    QDBusConnection::sessionBus().registerObject( QLatin1String( "/App" ), this );
 
     // Global keys
     m_actionCollection = new KActionCollection(this);
     KAction* a = 0;
 
-    if (KAuthorized::authorize("run_command")) {
-        a = m_actionCollection->addAction("Run Command");
+    if (KAuthorized::authorize(QLatin1String( "run_command" ))) {
+        a = m_actionCollection->addAction(QLatin1String( "Run Command" ));
         a->setText(i18n("Run Command"));
         a->setGlobalShortcut(KShortcut(Qt::ALT+Qt::Key_F2));
         connect(a, SIGNAL(triggered(bool)), SLOT(displayOrHide()));
 
-        a = m_actionCollection->addAction("Run Command on clipboard contents");
+        a = m_actionCollection->addAction(QLatin1String( "Run Command on clipboard contents" ));
         a->setText(i18n("Run Command on clipboard contents"));
         a->setGlobalShortcut(KShortcut(Qt::ALT+Qt::SHIFT+Qt::Key_F2));
         connect(a, SIGNAL(triggered(bool)), SLOT(displayWithClipboardContents()));
     }
 
-    a = m_actionCollection->addAction("Show System Activity");
+    a = m_actionCollection->addAction(QLatin1String( "Show System Activity" ));
     a->setText(i18n("Show System Activity"));
     a->setGlobalShortcut(KShortcut(Qt::CTRL+Qt::Key_Escape));
     connect(a, SIGNAL(triggered(bool)), SLOT(showTaskManager()));
 
-/*
- * TODO: doesn't this belong in the window manager?
-    a = m_actionCollection->addAction("Show Window List");
-    a->setText(i18n("Show Window List"));
-    a->setGlobalShortcut(KShortcut(Qt::ALT+Qt::Key_F5));
-    connect( a, SIGNAL(triggered(bool)), SLOT(slotShowWindowList()));
-*/
-    if (KAuthorized::authorize("switch_user")) {
-        a = m_actionCollection->addAction("Switch User");
+    if (KAuthorized::authorize(QLatin1String( "switch_user" ))) {
+        a = m_actionCollection->addAction(QLatin1String( "Switch User" ));
         a->setText(i18n("Switch User"));
         a->setGlobalShortcut(KShortcut(Qt::ALT+Qt::CTRL+Qt::Key_Insert));
         connect(a, SIGNAL(triggered(bool)), SLOT(switchUser()));
@@ -155,8 +150,8 @@ void KRunnerApp::initialize()
     //FIXME: lock/logout should be in the session management runner which also provides similar
     // functions
 #ifdef Q_WS_X11
-    if (KAuthorized::authorize("lock_screen")) {
-        a = m_actionCollection->addAction("Lock Session");
+    if (KAuthorized::authorize(QLatin1String( "lock_screen" ))) {
+        a = m_actionCollection->addAction(QLatin1String( "Lock Session" ));
         a->setText(i18n("Lock Session"));
         a->setGlobalShortcut(KShortcut(Qt::ALT+Qt::CTRL+Qt::Key_L));
         connect(a, SIGNAL(triggered(bool)), &m_saver, SLOT(Lock()));
@@ -189,7 +184,8 @@ void KRunnerApp::initialize()
 
 
     m_actionCollection->readSettings();
-    if (KAuthorized::authorize("run_command")) {
+    if (KAuthorized::authorize(QLatin1String( "run_command" ))) {
+        //m_runnerManager->setAllowedRunners(QStringList() << "shell");
         m_runnerManager->reloadConfiguration(); // pre-load the runners
 
         // Single runner mode actions shortcuts
@@ -214,7 +210,7 @@ void KRunnerApp::singleRunnerModeActionTriggered()
 
 void KRunnerApp::querySingleRunner(const QString& runnerId, const QString &term)
 {
-    if (!KAuthorized::authorize("run_command")) {
+    if (!KAuthorized::authorize(QLatin1String( "run_command" ))) {
         return;
     }
 
@@ -269,7 +265,7 @@ void KRunnerApp::showTaskManagerWithFilter(const QString &filterText)
 
 void KRunnerApp::display()
 {
-    if (!KAuthorized::authorize("run_command")) {
+    if (!KAuthorized::authorize(QLatin1String( "run_command" ))) {
         return;
     }
 
@@ -279,7 +275,7 @@ void KRunnerApp::display()
 
 void KRunnerApp::displaySingleRunner(const QString &runnerId)
 {
-    if (!KAuthorized::authorize("run_command")) {
+    if (!KAuthorized::authorize(QLatin1String( "run_command" ))) {
         return;
     }
 
@@ -290,7 +286,7 @@ void KRunnerApp::displaySingleRunner(const QString &runnerId)
 
 void KRunnerApp::displayOrHide()
 {
-    if (!KAuthorized::authorize("run_command")) {
+    if (!KAuthorized::authorize(QLatin1String( "run_command" ))) {
         m_interface->hide();
         return;
     }
@@ -314,7 +310,7 @@ void KRunnerApp::displayOrHide()
 
 void KRunnerApp::query(const QString &term)
 {
-    if (!KAuthorized::authorize("run_command")) {
+    if (!KAuthorized::authorize(QLatin1String( "run_command" ))) {
         return;
     }
 
@@ -323,7 +319,7 @@ void KRunnerApp::query(const QString &term)
 
 void KRunnerApp::displayWithClipboardContents()
 {
-    if (!KAuthorized::authorize("run_command")) {
+    if (!KAuthorized::authorize(QLatin1String( "run_command" ))) {
         return;
     }
 
@@ -333,7 +329,29 @@ void KRunnerApp::displayWithClipboardContents()
 
 void KRunnerApp::switchUser()
 {
-    m_interface->switchUser();
+    const KService::Ptr service = KService::serviceByStorageId(QLatin1String( "plasma-runner-sessions.desktop" ));
+    KPluginInfo info(service);
+
+    if (info.isValid()) {
+        SessList sessions;
+        KDisplayManager dm;
+        dm.localSessions(sessions);
+
+        if (sessions.isEmpty()) {
+            // no sessions to switch between, let's just start up another session directly
+            Plasma::AbstractRunner *sessionRunner = m_runnerManager->runner(info.pluginName());
+            if (sessionRunner) {
+                Plasma::QueryMatch switcher(sessionRunner);
+                sessionRunner->run(*m_runnerManager->searchContext(), switcher);
+            }
+        } else {
+            m_runnerManager->setSingleModeRunnerId(info.pluginName());
+            m_runnerManager->setSingleMode(true);
+            m_interface->display();
+            //TODO: ugh, magic strings. See sessions/sessionrunner.cpp
+            m_runnerManager->launchQuery(QLatin1String( "SESSIONS" ), info.pluginName());
+        }
+    }
 }
 
 void KRunnerApp::clearHistory()
