@@ -33,6 +33,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <stdlib.h>
 #include <signal.h>
 
+#include "scripting/client.h"
+#include "scripting/scripting.h"
+#include "scripting/workspaceproxy.h"
+
 #include "bridge.h"
 #include "group.h"
 #include "workspace.h"
@@ -124,7 +128,11 @@ Client::Client( Workspace* ws )
     , demandAttentionKNotifyTimer( NULL )
     , paintRedirector( 0 )
     , electricMaximizing( false )
+    , activitiesDefined( false )
+    , needsSessionInteract(false)
     { // TODO: Do all as initialization
+    
+    scriptCache = new QHash<QScriptEngine*, ClientResolution>();
 
     // Set the initial mapping state
     mapping_state = Withdrawn;
@@ -172,6 +180,9 @@ Client::Client( Workspace* ws )
     maxmode_restore = MaximizeRestore;
 
     cmap = None;
+    
+    //Client to workspace connections require that each
+    //client constructed be connected to the workspace wrapper
 
     // TabBoxClient
     m_tabBoxClient = new TabBox::TabBoxClientImpl();
@@ -191,6 +202,7 @@ Client::Client( Workspace* ws )
  */
 Client::~Client()
     {
+    //SWrapper::Client::clientRelease(this);
 #ifdef HAVE_XSYNC
     if( sync_alarm != None )
         XSyncDestroyAlarm( display(), sync_alarm );
@@ -204,6 +216,7 @@ Client::~Client()
     assert( !check_active_modal );
     delete bridge;
     delete m_tabBoxClient;
+    delete scriptCache;
     }
 
 // Use destroyClient() or releaseWindow(), Client instances cannot be deleted directly
@@ -211,7 +224,7 @@ void Client::deleteClient( Client* c, allowed_t )
     {
     delete c;
     }
-
+    
 /**
  * Releases the window. The client has done its job and the window is still existing.
  */
@@ -329,7 +342,6 @@ void Client::updateDecoration( bool check_workspace_pos, bool force )
     if( !force &&
      (( decoration == NULL && noBorder() ) || ( decoration != NULL && !noBorder() )))
         return;
-    bool do_show = false;
     QRect oldgeom = geometry();
     blockGeometryUpdates( true );
     if( force )
@@ -350,7 +362,6 @@ void Client::updateDecoration( bool check_workspace_pos, bool force )
         XMoveWindow( display(), decoration->widget()->winId(), -padding_left, -padding_top );
         move( calculateGravitation( false ));
         plainResize( sizeForClientSize( clientSize()), ForceGeometrySet );
-        do_show = true;
         paintRedirector = new PaintRedirector( decoration->widget());
         connect( paintRedirector, SIGNAL( paintPending()), SLOT( repaintDecorationPending()));
         resizeDecorationPixmaps();
@@ -579,10 +590,18 @@ void Client::resizeDecorationPixmaps()
     QRect lr, rr, tr, br;
     layoutDecorationRects( lr, tr, rr, br, DecorationRelative );
 
-    decorationPixmapTop = QPixmap( tr.size() );
-    decorationPixmapBottom = QPixmap( br.size() );
-    decorationPixmapLeft = QPixmap( lr.size() );
-    decorationPixmapRight = QPixmap( rr.size() );
+    if ( decorationPixmapTop.size() != tr.size() )
+        decorationPixmapTop = QPixmap( tr.size() );
+
+    if ( decorationPixmapBottom.size() != br.size() )
+        decorationPixmapBottom = QPixmap( br.size() );
+
+    if ( decorationPixmapLeft.size() != lr.size() )
+        decorationPixmapLeft = QPixmap( lr.size() );
+
+    if ( decorationPixmapRight.size() != rr.size() )
+        decorationPixmapRight = QPixmap( rr.size() );
+
 #ifdef HAVE_XRENDER
     if ( Extensions::renderAvailable() ) {
         // Make sure the pixmaps are created with alpha channels
@@ -710,6 +729,11 @@ void Client::setNoBorder( bool set )
     updateWindowRules();
     }
 
+void Client::checkNoBorder()
+    {
+    setNoBorder( app_noborder );
+    }
+
 void Client::updateShape()
     {
     if( shape() )
@@ -876,6 +900,16 @@ void Client::minimize( bool avoid_animation )
     {
     if( !isMinimizable() || isMinimized() )
         return;
+    
+    //Scripting call. Does not use a signal/slot mechanism
+    //as ensuring connections was a bit difficult between
+    //so many clients and the workspace
+    SWrapper::WorkspaceProxy* ws_wrap = SWrapper::WorkspaceProxy::instance();
+    if(ws_wrap != 0) {
+        ws_wrap->sl_clientMinimized(this);
+    }
+    
+    emit s_minimized();
 
     Notify::raise( Notify::Minimize );
 
@@ -889,6 +923,9 @@ void Client::minimize( bool avoid_animation )
     if( effects && !avoid_animation ) // TODO: Shouldn't it tell effects at least about the change?
         static_cast<EffectsHandlerImpl*>(effects)->windowMinimized( effectWindow());
 
+    // when tiling, request a rearrangement
+    workspace()->notifyTilingWindowMinimizeToggled( this );
+
     // Update states of all other windows in this group
     if( clientGroup() )
         clientGroup()->updateStates( this );
@@ -898,6 +935,13 @@ void Client::unminimize( bool avoid_animation )
     {
     if( !isMinimized())
         return;
+    
+    SWrapper::WorkspaceProxy* ws_wrap = SWrapper::WorkspaceProxy::instance();
+    if(ws_wrap != 0) {
+        ws_wrap->sl_clientUnminimized(this);
+    }
+    
+    emit s_unminimized();
 
     Notify::raise( Notify::UnMinimize );
     minimized = false;
@@ -905,9 +949,13 @@ void Client::unminimize( bool avoid_animation )
     updateAllowedActions();
     workspace()->updateMinimizedOfTransients( this );
     updateWindowRules();
+    workspace()->updateAllTiles();
     if( effects && !avoid_animation )
         static_cast<EffectsHandlerImpl*>( effects )->windowUnminimized( effectWindow() );
 
+    // when tiling, request a rearrangement
+    workspace()->notifyTilingWindowMinimizeToggled( this );
+
     // Update states of all other windows in this group
     if( clientGroup() )
         clientGroup()->updateStates( this );
@@ -1012,7 +1060,6 @@ void Client::setShade( ShadeMode mode )
     discardWindowPixmap();
     updateVisibility();
     updateAllowedActions();
-    workspace()->updateMinimizedOfTransients( this );
     if( decoration )
         decoration->shadeChange();
     updateWindowRules();
@@ -1079,6 +1126,14 @@ void Client::updateVisibility()
             internalHide( Allowed );
         return;
         }
+    if( !isOnCurrentActivity())
+        {
+        if( compositing() && options->hiddenPreviews != HiddenPreviewsNever )
+            internalKeep( Allowed );
+        else
+            internalHide( Allowed );
+        return;
+        }
     bool belongs_to_desktop = false;
     for( ClientList::ConstIterator it = group()->members().constBegin();
         it != group()->members().constEnd();
@@ -1418,6 +1473,15 @@ void Client::setSkipPager( bool b )
     updateWindowRules();
     }
 
+void Client::setSkipSwitcher( bool set )
+    {
+    set = rules()->checkSkipSwitcher( set );
+    if( set == skipSwitcher() )
+        return;
+    skip_switcher = set;
+    updateWindowRules();
+    }
+
 void Client::setModal( bool m )
     { // Qt-3.2 can have even modal normal windows :(
     if( modal == m )
@@ -1436,6 +1500,7 @@ void Client::setDesktop( int desktop )
     desktop = qMin( workspace()->numberOfDesktops(), rules()->checkDesktop( desktop ));
     if( desk == desktop )
         return;
+
     int was_desk = desk;
     desk = desktop;
     info->setDesktop( desktop );
@@ -1447,6 +1512,86 @@ void Client::setDesktop( int desktop )
         }
     if( decoration != NULL )
         decoration->desktopChange();
+
+    ClientList transients_stacking_order = workspace()->ensureStackingOrder( transients() );
+    for( ClientList::ConstIterator it = transients_stacking_order.constBegin();
+        it != transients_stacking_order.constEnd();
+        ++it )
+        (*it)->setDesktop( desktop );
+
+    if( isModal()) // if a modal dialog is moved, move the mainwindow with it as otherwise
+                      // the (just moved) modal dialog will confusingly return to the mainwindow with
+                      // the next desktop change
+        {
+        foreach( Client* c2, mainClients())
+            c2->setDesktop( desktop );
+        }
+
+    workspace()->updateFocusChains( this, Workspace::FocusChainMakeFirst );
+    updateVisibility();
+    updateWindowRules();
+
+    // Update states of all other windows in this group
+    if( clientGroup() )
+        clientGroup()->updateStates( this );
+    }
+
+/**
+ * Sets whether the client is on @p activity.
+ * If you remove it from its last activity, then it's on all activities.
+ *
+ * Note: If it was on all activities and you try to remove it from one, nothing will happen;
+ * I don't think that's an important enough use case to handle here.
+ */
+void Client::setOnActivity( const QString &activity, bool enable )
+    {
+    QStringList newActivitiesList = activities();
+    if( newActivitiesList.contains(activity) == enable ) //nothing to do
+        return;
+    if (enable)
+        {
+        QStringList allActivities = workspace()->activityList();
+        if( !allActivities.contains(activity) ) //bogus ID
+            return;
+        newActivitiesList.append(activity);
+        }
+    else
+        newActivitiesList.removeOne(activity);
+    setOnActivities( newActivitiesList );
+    }
+
+/**
+ * set exactly which activities this client is on
+ */
+void Client::setOnActivities( QStringList newActivitiesList )
+    {
+    QStringList allActivities = workspace()->activityList();
+    if( newActivitiesList.size() == allActivities.size() || newActivitiesList.isEmpty() )
+        {
+        setOnAllActivities(true);
+        return;
+        }
+
+    QByteArray joined = newActivitiesList.join(",").toAscii();
+    char *data = joined.data();
+    activityList = newActivitiesList;
+    XChangeProperty(display(), window(), atoms->activities, XA_STRING, 8,
+        PropModeReplace, (unsigned char *)data, joined.size());
+
+    updateActivities( false );
+    }
+
+/**
+ * update after activities changed
+ */
+void Client::updateActivities( bool includeTransients )
+    {
+    /* FIXME do I need this?
+    if( decoration != NULL )
+        decoration->desktopChange();
+        */
+    if( includeTransients )
+        workspace()->updateOnAllActivitiesOfTransients( this );
     workspace()->updateFocusChains( this, Workspace::FocusChainMakeFirst );
     updateVisibility();
     updateWindowRules();
@@ -1463,8 +1608,24 @@ void Client::setDesktop( int desktop )
  * isOnDesktop() instead.
  */
 int Client::desktop() const
-    {
+{
+    if (needsSessionInteract) {
+        return NET::OnAllDesktops;
+    }
     return desk;
+}
+
+/**
+ * Returns the list of activities the client window is on.
+ * if it's on all activities, the list will be empty.
+ * Don't use this, use isOnActivity() and friends (from class Toplevel)
+ */
+QStringList Client::activities() const
+    {
+    if (needsSessionInteract) {
+        return QStringList();
+    }
+    return activityList;
     }
 
 void Client::setOnAllDesktops( bool b )
@@ -1482,6 +1643,28 @@ void Client::setOnAllDesktops( bool b )
         clientGroup()->updateStates( this );
     }
 
+/**
+ * if @p on is true, sets on all activities.
+ * if it's false, sets it to only be on the current activity
+ */
+void Client::setOnAllActivities( bool on )
+    {
+    if( on == isOnAllActivities() )
+        return;
+    if( on )
+        {
+        activityList.clear();
+        XChangeProperty(display(), window(), atoms->activities, XA_STRING, 8,
+                        PropModeReplace, (const unsigned char *)"ALL", 3);
+        updateActivities( true );
+        }
+    else
+        {
+        setOnActivity(Workspace::self()->currentActivity(), true);
+        workspace()->updateOnAllActivitiesOfTransients( this );
+        }
+    }
+
 /**
  * Performs activation and/or raising of the window
  */
@@ -1704,7 +1887,9 @@ void Client::setClientShown( bool shown )
         //updateAllowedActions();
         if( options->inactiveTabsSkipTaskbar )
             setSkipTaskbar( true, false ); // TODO: Causes reshuffle of the taskbar
-        workspace()->updateFocusChains( this, Workspace::FocusChainMakeLast );
+        // Don't move tabs to the end of the list when another tab get's activated
+        if( !clientGroup() || clientGroup()->visible() == this )
+            workspace()->updateFocusChains( this, Workspace::FocusChainMakeLast );
         addWorkspaceRepaint( visibleRect() );
         }
     }
@@ -1729,6 +1914,10 @@ void Client::getWMHints()
     updateAllowedActions(); // Group affects isMinimizable()
     }
 
+void Client::sl_activated() {
+    emit s_activated();
+}
+
 void Client::getMotifHints()
     {
     bool mgot_noborder, mnoborder, mresize, mmove, mminimize, mmaximize, mclose;
@@ -2049,7 +2238,7 @@ void Client::cancelAutoRaise()
     autoRaiseTimer = 0;
     }
 
-void Client::debug( kdbgstream& stream ) const
+void Client::debug( QDebug& stream ) const
     {
     stream << "\'ID:" << window() << ";WMCLASS:" << resourceClass() << ":"
            << resourceName() << ";Caption:" << caption() << "\'";
@@ -2063,6 +2252,56 @@ QPixmap* kwin_get_menu_pix_hack()
     return &p;
     }
 
+void Client::checkActivities()
+    {
+    QStringList newActivitiesList;
+    QByteArray prop = getStringProperty(window(), atoms->activities);
+    activitiesDefined = !prop.isEmpty();
+    if (prop == "ALL") {
+        //copied from setOnAllActivities to avoid a redundant XChangeProperty.
+        if (!activityList.isEmpty()) {
+            activityList.clear();
+            updateActivities( true );
+        }
+        return;
+    }
+    if (prop.isEmpty()) {
+        //note: this makes it *act* like it's on all activities but doesn't set the property to 'ALL'
+        if (!activityList.isEmpty()) {
+            activityList.clear();
+            updateActivities( true );
+        }
+        return;
+    }
+
+    newActivitiesList = QString(prop).split(',');
+    if (newActivitiesList == activityList)
+        return; //expected change, it's ok.
+
+    //otherwise, somebody else changed it. we need to validate before reacting
+    QStringList allActivities = workspace()->activityList();
+    if (allActivities.isEmpty())
+        {
+        kDebug() << "no activities!?!?";
+        //don't touch anything, there's probably something bad going on and we don't wanna make it worse
+        return;
+        }
+    for ( int i = 0; i < newActivitiesList.size(); ++i )
+        {
+        if ( ! allActivities.contains( newActivitiesList.at(i) ) )
+            {
+            kDebug() << "invalid:" << newActivitiesList.at(i);
+            newActivitiesList.removeAt( i-- );
+            }
+        }
+    setOnActivities( newActivitiesList );
+    }
+
+void Client::setSessionInteract(bool needed)
+{
+    needsSessionInteract = needed;
+}
+
 } // namespace
 
 #include "client.moc"
