@@ -53,10 +53,6 @@ namespace Oxygen
         animation().data()->setTargetObject( this );
         animation().data()->setPropertyName( "progress" );
 
-        // setup connections
-        connect( animation().data(), SIGNAL( valueChanged( const QVariant& ) ), SLOT( updateBoundingRects( void ) ) );
-        connect( animation().data(), SIGNAL( finished( void ) ), SLOT( updateBoundingRects( void ) ) );
-
     }
 
     //________________________________________________________________
@@ -283,7 +279,6 @@ namespace Oxygen
     {
 
         // move close buttons
-        // this should move to ClientGroupItemDataList
         if( alsoUpdate ) client_.widget()->setUpdatesEnabled( false );
         for( int index = 0; index < count(); index++ )
         {
@@ -312,7 +307,7 @@ namespace Oxygen
         if( alsoUpdate )
         {
             client_.widget()->setUpdatesEnabled( true );
-            client_.widget()->update();
+            client_.updateTitleRect();
         }
 
     }
