@@ -44,14 +44,15 @@ FlipSwitchEffect::FlipSwitchEffect()
     , m_stop( false )
     , m_animation( false )
     , m_hasKeyboardGrab( false )
-    , m_captionFrame( EffectFrame::Styled )
+    , m_captionFrame( effects->effectFrame( EffectFrameStyled ) )
     {
     reconfigure( ReconfigureAll );
 
     // Caption frame
     m_captionFont.setBold( true );
     m_captionFont.setPointSize( m_captionFont.pointSize() * 2 );
-    m_captionFrame.setFont( m_captionFont );
+    m_captionFrame->setFont( m_captionFont );
+    m_captionFrame->enableCrossFade( true );
 
     KActionCollection* actionCollection = new KActionCollection( this );
     KAction* a = ( KAction* )actionCollection->addAction( "FlipSwitchCurrent" );
@@ -78,6 +79,7 @@ FlipSwitchEffect::~FlipSwitchEffect()
         {
         effects->unreserveElectricBorder( border );
         }
+    delete m_captionFrame;
     }
 
 bool FlipSwitchEffect::supported()
@@ -407,19 +409,11 @@ void FlipSwitchEffect::paintScreen( int mask, QRegion region, ScreenPaintData& d
         if( m_windowTitle )
             {
             // Render the caption frame
-            double opacity = 1.0;
-            opacity = m_startStopTimeLine.value();
-            QPixmap iconPixmap = m_selectedWindow->icon();
-            if( m_start || m_stop )
+            if( m_animation )
                 {
-                int alpha = 255.0f * m_startStopTimeLine.value();
-                QPixmap transparency = iconPixmap.copy( iconPixmap.rect() );
-                transparency.fill( QColor( 255, 255, 255, alpha ));
-                iconPixmap.setAlphaChannel( transparency.alphaChannel() );
+                m_captionFrame->setCrossFadeProgress( m_timeLine.value() );
                 }
-            m_captionFrame.setText( m_selectedWindow->caption() );
-            m_captionFrame.setIcon( iconPixmap );
-            m_captionFrame.render( region, opacity );
+            m_captionFrame->render( region, m_startStopTimeLine.value() );
             }
         }
     }
@@ -452,7 +446,7 @@ void FlipSwitchEffect::postPaintScreen()
             {
             m_stop = false;
             m_active = false;
-            m_captionFrame.free();
+            m_captionFrame->free();
             effects->setActiveFullScreenEffect( 0 );
             effects->addRepaintFull();
             qDeleteAll( m_windows );
@@ -522,6 +516,12 @@ void FlipSwitchEffect::paintWindow( EffectWindow* w, int mask, QRegion region, W
         if( w->isDesktop() )
             {
             // desktop is painted in normal way
+            if( m_windows.contains( w ) )
+                {
+                m_windows[ w ]->opacity = data.opacity;
+                m_windows[ w ]->brightness = data.brightness;
+                m_windows[ w ]->saturation = data.saturation;
+                }
             effects->paintWindow( w, mask, region, data );
             return;
             }
@@ -612,6 +612,8 @@ void FlipSwitchEffect::tabBoxUpdated()
                         }
                     }
                 m_selectedWindow = effects->currentTabBoxWindow();
+                m_captionFrame->setText( m_selectedWindow->caption() );
+                m_captionFrame->setIcon( m_selectedWindow->icon() );
                 }
             }
         effects->addRepaintFull();
@@ -713,8 +715,10 @@ void FlipSwitchEffect::setActive( bool activate, FlipSwitchMode mode )
             m_screenArea.height() * 0.1f + m_screenArea.y() - QFontMetrics( m_captionFont ).height(),
             m_screenArea.width() * 0.5f,
             QFontMetrics( m_captionFont ).height() );
-        m_captionFrame.setGeometry( frameRect );
-        m_captionFrame.setIconSize( QSize( frameRect.height(), frameRect.height() ));
+        m_captionFrame->setGeometry( frameRect );
+        m_captionFrame->setIconSize( QSize( frameRect.height(), frameRect.height() ));
+        m_captionFrame->setText( m_selectedWindow->caption() );
+        m_captionFrame->setIcon( m_selectedWindow->icon() );
         effects->addRepaintFull();
         }
     else
@@ -813,8 +817,11 @@ bool FlipSwitchEffect::borderActivated(ElectricBorder border)
 
 bool FlipSwitchEffect::isSelectableWindow( EffectWindow* w ) const
     {
-    if( w->isSpecialWindow() || w->isUtility() )
+    // desktop windows might be included
+    if( (w->isSpecialWindow() && !w->isDesktop()) || w->isUtility() )
         return false;
+    if( w->isDesktop() )
+        return (m_mode == TabboxMode && effects->currentTabBoxWindowList().contains( w ));
     if( w->isDeleted() )
         return false;
     if( !w->acceptsFocus() )
@@ -979,6 +986,8 @@ void FlipSwitchEffect::grabbedKeyboardEvent(QKeyEvent* e)
                     }
                 if( found )
                     {
+                    m_captionFrame->setText( m_selectedWindow->caption() );
+                    m_captionFrame->setIcon( m_selectedWindow->icon() );
                     scheduleAnimation( DirectionForward );
                     }
                 break;
@@ -1012,6 +1021,8 @@ void FlipSwitchEffect::grabbedKeyboardEvent(QKeyEvent* e)
                     }
                 if( found )
                     {
+                    m_captionFrame->setText( m_selectedWindow->caption() );
+                    m_captionFrame->setIcon( m_selectedWindow->icon() );
                     scheduleAnimation( DirectionBackward );
                     }
                 break;
