@@ -55,6 +55,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 namespace KWin
 {
 
+extern int currentRefreshRate();
+    
 // ****************************************
 // WinInfo
 // ****************************************
@@ -510,18 +512,16 @@ bool Workspace::workspaceEvent( XEvent * e )
                 {
 #ifdef HAVE_XRANDR
                 XRRUpdateConfiguration( e );
+#endif
                 if( compositing() )
                     {
                     // desktopResized() should take care of when the size or
                     // shape of the desktop has changed, but we also want to
                     // catch refresh rate changes
-                    XRRScreenConfiguration *config = XRRGetScreenInfo( display(), rootWindow() );
-                    bool changed = ( xrrRefreshRate != XRRConfigCurrentRate( config ));
-                    XRRFreeScreenConfigInfo( config );
-                    if( changed )
+                    if( xrrRefreshRate != currentRefreshRate() )
                         compositeResetTimer.start( 0 );
                     }
-#endif
+
                 }
             else if( e->type == Extensions::syncAlarmNotifyEvent() && Extensions::syncAvailable())
                 {
@@ -942,6 +942,8 @@ void Client::propertyNotifyEvent( XPropertyEvent* e )
                 getMotifHints();
             else if( e->atom == atoms->net_wm_sync_request_counter )
                 getSyncCounter();
+            else if( e->atom == atoms->activities )
+                checkActivities();
             break;
         }
     }
@@ -1449,19 +1451,55 @@ void Client::checkQuickTilingMaximizationZones( int xroot, int yroot )
         if( screen->geom().contains( QPoint( xroot, yroot )))
             {
             if( options->electricBorderTiling() &&
-                xroot <= screen->geom().x() + 20 )
+                xroot <= screen->geom().x() + 20 &&
+                yroot > screen->geom().y() + screen->geom().height()/4 &&
+                yroot < screen->geom().y() + screen->geom().height() - screen->geom().height()/4 )
                 {
                 setElectricBorderMode( ElectricLeftMode );
                 setElectricBorderMaximizing( true );
                 return;
                 }
             else if( options->electricBorderTiling() &&
-                xroot >= screen->geom().x() + screen->geom().width() - 20 )
+                xroot <= screen->geom().x() + 20 &&
+                yroot <= screen->geom().y() + screen->geom().height()/4 )
+                {
+                setElectricBorderMode( ElectricTopLeftMode );
+                setElectricBorderMaximizing( true );
+                return;
+                }
+            else if( options->electricBorderTiling() &&
+                xroot <= screen->geom().x() + 20 &&
+                yroot >= screen->geom().y() + screen->geom().height() - screen->geom().height()/4 )
+                {
+                setElectricBorderMode( ElectricBottomLeftMode );
+                setElectricBorderMaximizing( true );
+                return;
+                }
+            else if( options->electricBorderTiling() &&
+                xroot >= screen->geom().x() + screen->geom().width() - 20 &&
+                yroot > screen->geom().y() + screen->geom().height()/4 &&
+                yroot < screen->geom().y() + screen->geom().height() - screen->geom().height()/4 )
                 {
                 setElectricBorderMode( ElectricRightMode );
                 setElectricBorderMaximizing( true );
                 return;
                 }
+            else if( options->electricBorderTiling() &&
+                xroot >= screen->geom().x() + screen->geom().width() - 20 &&
+                yroot <= screen->geom().y() + screen->geom().height()/4 )
+                {
+                setElectricBorderMode( ElectricTopRightMode );
+                setElectricBorderMaximizing( true );
+                return;
+                }
+            else if( options->electricBorderTiling() &&
+                xroot >= screen->geom().x() + screen->geom().width() - 20 &&
+                yroot >= screen->geom().y() + screen->geom().height() - screen->geom().height()/4 )
+                {
+                setElectricBorderMode( ElectricBottomRightMode );
+                setElectricBorderMaximizing( true );
+                return;
+                }
             else if( options->electricBorderMaximize() &&
                 yroot <= screen->geom().y() + 5 && isMaximizable() )
                 {
@@ -1698,6 +1736,7 @@ void Client::syncEvent( XSyncAlarmNotifyEvent* e )
             sync_timeout = NULL;
             if( sync_resize_pending )
                 performMoveResize();
+            sync_resize_pending = false;
             }
         }
     }
