@@ -38,8 +38,7 @@
 #include <kdecoration_plugins_p.h>
 #include <QX11Info>
 #include <kwindowsystem.h>
-
-// FRAME the preview doesn't update to reflect the changes done in the kcm
+#include <QTextDocument>
 
 KDecorationPreview::KDecorationPreview( QWidget* parent )
     :   QWidget( parent )
@@ -90,7 +89,7 @@ bool KDecorationPreview::recreateDecoration( KDecorationPlugins* plugins )
     //deco[Active]->widget()->show();
 
     //deco[Inactive]->widget()->render( this, deco[Inactive]->widget()->mapToParent( QPoint(0,0) ) );
-    
+
     return true;
     }
 
@@ -109,6 +108,7 @@ void KDecorationPreview::disablePreview()
 
 void KDecorationPreview::paintEvent( QPaintEvent* e )
     {
+    Q_UNUSED( e );
     QPainter painter( this );
     QPoint delta = mapTo( window(), QPoint(0, 0) );
 
@@ -124,6 +124,26 @@ void KDecorationPreview::paintEvent( QPaintEvent* e )
         }
     }
 
+QPixmap KDecorationPreview::preview( QTextDocument* document, QWidget* widget )
+    {
+    Q_UNUSED( document );
+    Q_UNUSED( widget );
+    QPixmap pixmap( size() );
+    pixmap.fill( Qt::transparent );
+
+    if ( deco[Inactive] )
+        {
+        QWidget *w = deco[Inactive]->widget();
+        w->render( &pixmap, w->mapToParent( QPoint(0, 0) ) );
+        }
+    if ( deco[Active] )
+        {
+        QWidget *w = deco[Active]->widget();
+        w->render( &pixmap, w->mapToParent( QPoint(0, 0) ) );
+        }
+    return pixmap;
+    }
+
 void KDecorationPreview::resizeEvent( QResizeEvent* e )
     {
     QWidget::resizeEvent( e );
@@ -466,6 +486,67 @@ bool KDecorationPreviewBridge::compositingActive() const
     return KWindowSystem::compositingActive();
     }
 
+QRect KDecorationPreviewBridge::transparentRect() const
+    {
+    return QRect();
+    }
+
+// Window tabbing
+
+bool KDecorationPreviewBridge::isClientGroupActive()
+    {
+    return active;
+    }
+
+QList< ClientGroupItem > KDecorationPreviewBridge::clientGroupItems() const
+    {
+    return QList< ClientGroupItem >() << ClientGroupItem(
+        active ? "Active Window" : "Inactive Window", icon() );
+    }
+
+long KDecorationPreviewBridge::itemId( int )
+    {
+    return 0;
+    }
+
+int KDecorationPreviewBridge::visibleClientGroupItem()
+    {
+    return 0;
+    }
+
+void KDecorationPreviewBridge::setVisibleClientGroupItem( int )
+    {
+    }
+
+void KDecorationPreviewBridge::moveItemInClientGroup( int, int )
+    {
+    }
+
+void KDecorationPreviewBridge::moveItemToClientGroup( long, int )
+    {
+    }
+
+void KDecorationPreviewBridge::removeFromClientGroup( int, const QRect& )
+    {
+    }
+
+void KDecorationPreviewBridge::closeClientGroupItem( int )
+    {
+    }
+
+void KDecorationPreviewBridge::closeAllInClientGroup()
+    {
+    }
+
+void KDecorationPreviewBridge::displayClientMenu( int, const QPoint& )
+    {
+    }
+
+KDecoration::WindowOperation KDecorationPreviewBridge::buttonToWindowOperation( Qt::MouseButtons )
+    {
+    return KDecoration::NoOp;
+    }
+
 KDecorationPreviewOptions::KDecorationPreviewOptions()
     {
     customBorderSize = BordersCount; // invalid
