@@ -84,6 +84,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "rules.h"
 #include "unmanaged.h"
 #include "deleted.h"
+#include "effects.h"
 #include <QX11Info>
 
 namespace KWin
@@ -262,7 +263,7 @@ Client* Workspace::topClientOnDesktop( int desktop, int screen, bool unconstrain
          i >= 0;
          --i )
         {
-        if( list.at( i )->isOnDesktop( desktop ) && list.at( i )->isShown( false ))
+        if( list.at( i )->isOnDesktop( desktop ) && list.at( i )->isShown( false ) && list.at(i)->isOnCurrentActivity())
             {
             if( screen != -1 && list.at( i )->screen() != screen )
                 continue;
@@ -389,10 +390,12 @@ void Workspace::raiseClient( Client* c, bool nogroup )
 
     if( !nogroup && c->isTransient())
         {
-        ClientList wins = ensureStackingOrder( c->group()->members());
-        foreach( Client* c2, wins )
-            if( c2 != c )
-                raiseClient( c2, true );
+        ClientList transients;
+        Client *transient_parent = c;
+        while ((transient_parent = transient_parent->transientFor()))
+            transients << transient_parent;
+        foreach( transient_parent, transients )
+            raiseClient( transient_parent, true );
         }
 
     unconstrained_stacking_order.removeAll( c );
@@ -454,21 +457,14 @@ void Workspace::lowerClientRequest( Client* c, NET::RequestSource src, Time /*ti
         lowerClientWithinApplication( c );
     }
 
-void Workspace::restackClientUnderActive( Client* c )
-    {
-    if( c->isTopMenu())
-        return;
-    if( !active_client || active_client == c )
-        {
-        raiseClient( c );
-        return;
-        }
 
-    assert( unconstrained_stacking_order.contains( active_client ));
-    if( Client::belongToSameApplication( active_client, c ))
+void Workspace::restack( Client* c, Client* under )
+    {
+    assert( unconstrained_stacking_order.contains( under ));
+    if( Client::belongToSameApplication( under, c ))
         { // put it below the active window if it's the same app
         unconstrained_stacking_order.removeAll( c );
-        unconstrained_stacking_order.insert( unconstrained_stacking_order.indexOf( active_client ), c );
+        unconstrained_stacking_order.insert( unconstrained_stacking_order.indexOf( under ), c );
         }
     else
         { // put in the stacking order below _all_ windows belonging to the active application
@@ -476,7 +472,7 @@ void Workspace::restackClientUnderActive( Client* c )
              it != unconstrained_stacking_order.end();
              ++it )
             { // TODO ignore topmenus?
-            if( Client::belongToSameApplication( active_client, *it ))
+            if( Client::belongToSameApplication( under, *it ))
                 {
                 if( *it != c )
                     {
@@ -492,12 +488,12 @@ void Workspace::restackClientUnderActive( Client* c )
          desktop <= numberOfDesktops();
          ++desktop )
         { // do for every virtual desktop to handle the case of onalldesktop windows
-        if( c->wantsTabFocus() && c->isOnDesktop( desktop ) && focus_chain[ desktop ].contains( active_client ))
+        if( c->wantsTabFocus() && c->isOnDesktop( desktop ) && focus_chain[ desktop ].contains( under ))
             {
-            if( Client::belongToSameApplication( active_client, c ))
+            if( Client::belongToSameApplication( under, c ))
                 { // put it after the active window if it's the same app
                 focus_chain[ desktop ].removeAll( c );
-                focus_chain[ desktop ].insert( focus_chain[ desktop ].indexOf( active_client ), c );
+                focus_chain[ desktop ].insert( focus_chain[ desktop ].indexOf( under ), c );
                 }
             else
                 { // put it in focus_chain[currentDesktop()] after all windows belonging to the active applicationa
@@ -506,7 +502,7 @@ void Workspace::restackClientUnderActive( Client* c )
                      i >= 0;
                      --i )
                     {
-                    if( Client::belongToSameApplication( active_client, focus_chain[ desktop ].at( i )))
+                    if( Client::belongToSameApplication( under, focus_chain[ desktop ].at( i )))
                         {
                         focus_chain[ desktop ].insert( i, c );
                         break;
@@ -516,12 +512,12 @@ void Workspace::restackClientUnderActive( Client* c )
             }
         }
     // the same for global_focus_chain
-    if( c->wantsTabFocus() && global_focus_chain.contains( active_client ))
+    if( c->wantsTabFocus() && global_focus_chain.contains( under ))
         {
-        if( Client::belongToSameApplication( active_client, c ))
+        if( Client::belongToSameApplication( under, c ))
             {
             global_focus_chain.removeAll( c );
-            global_focus_chain.insert( global_focus_chain.indexOf( active_client ), c );
+            global_focus_chain.insert( global_focus_chain.indexOf( under ), c );
             }
         else
             {
@@ -530,7 +526,7 @@ void Workspace::restackClientUnderActive( Client* c )
                   i >= 0;
                   --i )
                 {
-                if( Client::belongToSameApplication( active_client, global_focus_chain.at( i ) ))
+                if( Client::belongToSameApplication( under, global_focus_chain.at( i ) ))
                     {
                     global_focus_chain.insert( i, c );
                     break;
@@ -541,6 +537,18 @@ void Workspace::restackClientUnderActive( Client* c )
     updateStackingOrder();
     }
 
+void Workspace::restackClientUnderActive( Client* c )
+    {
+    if( c->isTopMenu())
+        return;
+    if( !active_client || active_client == c )
+        {
+        raiseClient( c );
+        return;
+        }
+    restack( c, active_client );
+    }
+    
 void Workspace::restoreSessionStackingOrder( Client* c )
     {
     if( c->sessionStackingOrder() < 0 )
@@ -703,7 +711,11 @@ void Workspace::blockStackingUpdates( bool block )
         }
     else // !block
         if( --block_stacking_updates == 0 )
+            {
             updateStackingOrder( blocked_propagating_new_clients );
+            if( effects )
+                static_cast<EffectsHandlerImpl*>( effects )->checkInputWindowStacking();
+            }
     }
 
 // Ensure list is in stacking order
@@ -818,6 +830,10 @@ void Client::setKeepAbove( bool b )
         decoration->emitKeepAboveChanged( keepAbove());
     workspace()->updateClientLayer( this );
     updateWindowRules();
+
+    // Update states of all other windows in this group
+    if( clientGroup() )
+        clientGroup()->updateStates( this );
     }
 
 void Client::setKeepBelow( bool b )
@@ -837,6 +853,10 @@ void Client::setKeepBelow( bool b )
         decoration->emitKeepBelowChanged( keepBelow());
     workspace()->updateClientLayer( this );
     updateWindowRules();
+
+    // Update states of all other windows in this group
+    if( clientGroup() )
+        clientGroup()->updateStates( this );
     }
 
 Layer Client::layer() const
