@@ -54,9 +54,10 @@ class QKeyEvent;
 namespace KWin
 {
 
-
 class EffectWindow;
 class EffectWindowGroup;
+class EffectFrame;
+class EffectFramePrivate;
 class Effect;
 class WindowQuad;
 class GLRenderTarget;
@@ -170,7 +171,7 @@ X-KDE-Library=kwin4_effect_cooleffect
 
 #define KWIN_EFFECT_API_MAKE_VERSION( major, minor ) (( major ) << 8 | ( minor ))
 #define KWIN_EFFECT_API_VERSION_MAJOR 0
-#define KWIN_EFFECT_API_VERSION_MINOR 112
+#define KWIN_EFFECT_API_VERSION_MINOR 157
 #define KWIN_EFFECT_API_VERSION KWIN_EFFECT_API_MAKE_VERSION( \
     KWIN_EFFECT_API_VERSION_MAJOR, KWIN_EFFECT_API_VERSION_MINOR )
 
@@ -193,7 +194,21 @@ enum DataRole
     WindowAddedGrabRole = 1,
     WindowClosedGrabRole,
     WindowMinimizedGrabRole,
-    WindowUnminimizedGrabRole
+    WindowUnminimizedGrabRole,
+    WindowForceBlurRole, ///< For fullscreen effects to enforce blurring of windows,
+    WindowBlurBehindRole, ///< For single windows to blur behind
+    LanczosCacheRole
+    };
+
+/**
+ * Style types used by @ref EffectFrame.
+ * @since 4.6
+ */
+enum EffectFrameStyle
+    {
+    EffectFrameNone, ///< Displays no frame around the contents.
+    EffectFrameUnstyled, ///< Displays a basic box around the contents.
+    EffectFrameStyled ///< Displays a Plasma-styled frame around the contents.
     };
 
 /**
@@ -294,7 +309,25 @@ class KWIN_EXPORT Effect
             /**
             * Temporary solution since (_OPAQUE | _TRANSLUCENT) is not working currently.
             **/
-            PAINT_DECORATION_ONLY = 1 << 7
+            PAINT_DECORATION_ONLY = 1 << 7,
+            /**
+             * Window will be painted with a lanczos filter.
+             **/
+            PAINT_WINDOW_LANCZOS = 1 << 8,
+            /**
+             * Same as PAINT_SCREEN_WITH_TRANSFORMED_WINDOWS but does not trigger
+             * full repaints of the screen. If this flag is used the effect has
+             * to ensure by itself that the correct areas are repainted. If not
+             * handled correctly it will cause rendering glitches.
+             * Use with care!
+             * @since 4.6
+             **/
+            PAINT_SCREEN_WITH_TRANSFORMED_WINDOWS_WITHOUT_FULL_REPAINTS = 1 << 9
+        };
+
+        enum Feature
+        {
+            Nothing = 0, Resize, GeometryTip
         };
 
         /**
@@ -375,6 +408,24 @@ class KWIN_EXPORT Effect
          **/
         virtual void postPaintWindow( EffectWindow* w );
 
+        /**
+         * This method is called directly before painting an @ref EffectFrame.
+         * You can implement this method if you need to bind a shader or perform
+         * other operations before the frame is rendered.
+         * @param frame The EffectFrame which will be rendered
+         * @param region Region to restrict painting to
+         * @param opacity Opacity of text/icon
+         * @param frameOpacity Opacity of background
+         * @since 4.6
+         **/
+        virtual void paintEffectFrame( EffectFrame* frame, QRegion region, double opacity, double frameOpacity );
+
+        /**
+         * Called on Transparent resizes.
+         * return true if your effect substitutes the XOR rubberband
+        */
+        virtual bool provides( Feature );
+
         /**
          * Can be called to draw multiple copies (e.g. thumbnails) of a window.
          * You can change window's opacity/brightness/etc here, but you can't
@@ -433,6 +484,13 @@ class KWIN_EXPORT Effect
         virtual void tabBoxKeyEvent( QKeyEvent* event );
         virtual bool borderActivated( ElectricBorder border );
 
+        /**
+        * called when the number of currently existing desktops is changed.
+        * @param old The previous number of desktops in used.
+        * @see EffectsHandler::numberOfDesktops.
+        */
+        virtual void numberDesktopsChanged( int old );
+
         static int displayWidth();
         static int displayHeight();
         static QPoint cursorPos();
@@ -543,6 +601,7 @@ class KWIN_EXPORT EffectsHandler
         virtual void prePaintWindow( EffectWindow* w, WindowPrePaintData& data, int time ) = 0;
         virtual void paintWindow( EffectWindow* w, int mask, QRegion region, WindowPaintData& data ) = 0;
         virtual void postPaintWindow( EffectWindow* w ) = 0;
+        virtual void paintEffectFrame( EffectFrame* frame, QRegion region, double opacity, double frameOpacity ) = 0;
         virtual void drawWindow( EffectWindow* w, int mask, QRegion region, WindowPaintData& data ) = 0;
         virtual void buildQuads( EffectWindow* w, WindowQuadList& quadList ) = 0;
         virtual QRect transformWindowDamage( EffectWindow* w, const QRect& r );
@@ -593,6 +652,10 @@ class KWIN_EXPORT EffectsHandler
          * Set the current desktop to @a desktop.
          */
         virtual void setCurrentDesktop( int desktop ) = 0;
+        /**
+        * Sets the total number of desktops to @a desktops.
+        */
+        virtual void setNumberOfDesktops( int desktops ) = 0;
         /**
          * @returns The size of desktop layout in grid units.
          */
@@ -699,6 +762,7 @@ class KWIN_EXPORT EffectsHandler
 
         virtual void pushRenderTarget(GLRenderTarget* target) = 0;
         virtual GLRenderTarget* popRenderTarget() = 0;
+        virtual bool isRenderTargetBound() = 0;
 
         /**
          * Schedules the entire workspace to be repainted next time.
@@ -722,6 +786,8 @@ class KWIN_EXPORT EffectsHandler
          Note that even events that haven't been registered for can be received.
         */
         virtual void registerPropertyType( long atom, bool reg ) = 0;
+        virtual QByteArray readRootProperty( long atom, long type, int format ) const = 0;
+        virtual void deleteRootProperty( long atom ) const = 0;
 
         /**
          * Returns @a true if the active window decoration has shadow API hooks.
@@ -729,38 +795,38 @@ class KWIN_EXPORT EffectsHandler
         virtual bool hasDecorationShadows() const = 0;
 
         /**
-         * @deprecated
-         * @see EffectFrame
-         * Paints given text onto screen, possibly in elided form
-         * @param text
-         * @param center center point of the painted text
-         * @param maxwidth if text is longer than this, is will be elided
-         * @param color color of the text, may contain alpha
-         * @param font font for the text
-         **/
-        bool paintText( const QString& text, const QPoint& center, int maxwidth,
-                        const QColor& color, const QFont& font = QFont() );
-        /**
-         * @deprecated
-         * @see EffectFrame
+         * Returns @a true if the window decorations use the alpha channel, and @a false otherwise.
+         * @since 4.5
          */
-        bool paintText( const QString& text, const QRect& rect, const QColor& color,
-                        const QFont& font = QFont(), const Qt::Alignment& alignment = Qt::AlignCenter );
-        /**
-         * @deprecated
-         * @see EffectFrame
-         */
-        bool paintTextWithBackground( const QString& text, const QPoint& center, int maxwidth,
-                                      const QColor& color, const QColor& bgcolor,
-                                      const QFont& font = QFont() );
-        /**
-         * @deprecated
-         * @see EffectFrame
-         */
-        bool paintTextWithBackground( const QString& text, const QRect& rect, const QColor& color,
-                                      const QColor& bgcolor, const QFont& font = QFont(),
-                                      const Qt::Alignment& alignment = Qt::AlignCenter );
+        virtual bool decorationsHaveAlpha() const = 0;
 
+        /**
+         * Returns @a true if the window decorations support blurring behind the decoration, and @a false otherwise
+         * @since 4.6
+         */
+        virtual bool decorationSupportsBlurBehind() const = 0;
+
+        /**
+         * Checks if the driver is on given blacklist.
+         * The format of the blacklist is driver identifier as key (e.g. Intel) with a list of
+         * concrete driver render strings as the values. The renderer string consists of GL_RENDERER
+         * and GL_VERSION separated by colon dash colon. E.g.: GeForce 9400M/PCI/SSE2:-:3.2.0 NVIDIA 195.36.24
+         * This method is only used for OpenGL compositing. If not using OpenGL it will return false.
+         * @returns true if the driver is blacklisted, false otherwise
+         * @since 4.5
+         */
+        bool checkDriverBlacklist( const KConfigGroup& blacklist );
+
+        /**
+         * Creates a new frame object. If the frame does not have a static size
+         * then it will be located at @a position with @a alignment. A
+         * non-static frame will automatically adjust its size to fit the contents.
+         * @returns A new @ref EffectFrame. It is the responsibility of the caller to delete the
+         * EffectFrame.
+         * @since 4.6
+         */
+        virtual EffectFrame* effectFrame( EffectFrameStyle style, bool staticSize = true,
+                                          const QPoint& position = QPoint( -1, -1 ), Qt::Alignment alignment = Qt::AlignCenter ) const = 0;
 
         /**
          * Sends message over DCOP to reload given effect.
@@ -809,7 +875,9 @@ class KWIN_EXPORT EffectWindow
             /**  Window will not be painted because it is minimized  */
             PAINT_DISABLED_BY_MINIMIZE     = 1 << 3,
             /**  Window will not be painted because it is not the active window in a client group  */
-            PAINT_DISABLED_BY_CLIENT_GROUP = 1 << 4
+            PAINT_DISABLED_BY_CLIENT_GROUP = 1 << 4,
+            /**  Window will not be painted because it's not on the current activity  */
+            PAINT_DISABLED_BY_ACTIVITY     = 1 << 5
         };
 
         EffectWindow();
@@ -856,6 +924,12 @@ class KWIN_EXPORT EffectWindow
          * Geometry of the actual window contents inside the whole (including decorations) window.
          */
         virtual QRect contentsRect() const = 0;
+        /**
+         * Geometry of the transparent rect in the decoration.
+         * May be different from contentsRect() if the decoration is extended into the client area.
+         * @since 4.5
+         */
+        virtual QRect decorationInnerRect() const = 0;
         bool hasDecoration() const;
         virtual QByteArray readProperty( long atom, long type, int format ) const = 0;
         virtual void deleteProperty( long atom ) const = 0;
@@ -968,6 +1042,12 @@ class KWIN_EXPORT EffectWindow
         virtual EffectWindow* findModal() = 0;
         virtual EffectWindowList mainWindows() const = 0;
 
+        /**
+        * Returns whether the window should be excluded from window switching effects.
+        * @since 4.5
+        */
+        virtual bool isSkipSwitcher() const = 0;
+
         /**
          * Returns the unmodified window quad list. Can also be used to force rebuilding.
          */
@@ -1582,6 +1662,12 @@ class KWIN_EXPORT WindowMotionManager
          * window.
          */
         QRectF transformedGeometry( EffectWindow *w ) const;
+        /**
+         * Sets the current transformed geometry of a registered window to the given geometry.
+         * @see transformedGeometry
+         * @since 4.5
+         */
+        void setTransformedGeometry( EffectWindow *w, const QRectF &geometry );
         /**
          * Retrieve the current target geometry of a registered
          * window.
@@ -1635,65 +1721,61 @@ class KWIN_EXPORT WindowMotionManager
  * another that doesn't.
  * It is recommended to use this class whenever displaying text.
  */
-class KWIN_EXPORT EffectFrame : public QObject
+class KWIN_EXPORT EffectFrame
     {
-    Q_OBJECT
-
     public:
-        enum Style
-            {
-            None, ///< Displays no frame around the contents.
-            Unstyled, ///< Displays a basic box around the contents.
-            Styled ///< Displays a Plasma-styled frame around the contents.
-            };
-
-        /**
-         * Creates a new frame object. If the frame does not have a static size
-         * then it will be located at @a position with @a alignment. A
-         * non-static frame will automatically adjust its size to fit the
-         * contents.
-         */
-        explicit EffectFrame( Style style, bool staticSize = true, QPoint position = QPoint( -1, -1 ),
-            Qt::Alignment alignment = Qt::AlignCenter );
-        ~EffectFrame();
+        EffectFrame();
+        virtual ~EffectFrame();
 
         /**
          * Delete any existing textures to free up graphics memory. They will
          * be automatically recreated the next time they are required.
          */
-        void free();
+        virtual void free() = 0;
 
         /**
          * Render the frame.
          */
-        void render( QRegion region = infiniteRegion(), double opacity = 1.0, double frameOpacity = 1.0 );
+        virtual void render( QRegion region = infiniteRegion(), double opacity = 1.0, double frameOpacity = 1.0 ) = 0;
 
-        void setPosition( const QPoint& point );
+        virtual void setPosition( const QPoint& point ) = 0;
         /**
          * Set the text alignment for static frames and the position alignment
          * for non-static.
          */
-        inline void setAlignment( Qt::Alignment alignment )
-            { m_alignment = alignment; }; // Doesn't change geometry
-        void setGeometry( const QRect& geometry, bool force = false );
-        inline QRect geometry() const // Inner/contents geometry
-            { return m_geometry; };
+        virtual void setAlignment( Qt::Alignment alignment ) = 0;
+        virtual Qt::Alignment alignment() const = 0;
+        virtual void setGeometry( const QRect& geometry, bool force = false ) = 0;
+        virtual const QRect& geometry() const = 0;
 
-        void setText( const QString& text );
-        inline QString text() const
-            { return m_text; };
-        void setFont( const QFont& font );
-        inline QFont font() const
-            { return m_font; };
+        virtual void setText( const QString& text ) = 0;
+        virtual const QString& text() const = 0;
+        virtual void setFont( const QFont& font ) = 0;
+        virtual const QFont& font() const = 0;
         /**
          * Set the icon that will appear on the left-hand size of the frame.
          */
-        void setIcon( const QPixmap& icon );
-        inline QPixmap icon() const
-            { return m_icon; };
-        void setIconSize( const QSize& size );
-        inline QSize iconSize() const
-            { return m_iconSize; };
+        virtual void setIcon( const QPixmap& icon ) = 0;
+        virtual const QPixmap& icon() const = 0;
+        virtual void setIconSize( const QSize& size ) = 0;
+        virtual const QSize& iconSize() const = 0;
+
+        /**
+         * Sets the geometry of a selection.
+         * To remove the selection set a null rect.
+         * This is only available if the an styled EffectFrame is used.
+         * @param selection The geometry of the selection in screen coordinates.
+         **/
+        virtual void setSelection( const QRect& selection ) = 0;
+
+        /**
+         * @param shader The GLShader for rendering.
+         **/
+        virtual void setShader( GLShader* shader ) = 0;
+        /**
+         * @returns The GLShader used for rendering or null if none.
+         **/
+        virtual GLShader* shader() const = 0;
 
         /**
          * The foreground text color as specified by the default Plasma theme.
@@ -1701,44 +1783,45 @@ class KWIN_EXPORT EffectFrame : public QObject
         static QColor styledTextColor();
 
         /**
-         * Clean up all static texture data. Called when compositing is being disabled.
-         * @internal
-         */
-        static void cleanup();
-
-    private Q_SLOTS:
-        void plasmaThemeChanged();
+         * If @p enable is @c true cross fading between icons and text is enabled
+         * By default disabled. Use setCrossFadeProgress to cross fade.
+         * Cross Fading is currently only available if OpenGL is used.
+         * @param enable @c true enables cross fading, @c false disables it again
+         * @see isCrossFade
+         * @see setCrossFadeProgress
+         * @since 4.6
+         **/
+        void enableCrossFade( bool enable );
+        /**
+         * @returns @c true if cross fading is enabled, @c false otherwise
+         * @see enableCrossFade
+         * @since 4.6
+         **/
+        bool isCrossFade() const;
+        /**
+         * Sets the current progress for cross fading the last used icon/text
+         * with current icon/text to @p progress.
+         * A value of 0.0 means completely old icon/text, a value of 1.0 means
+         * completely current icon/text.
+         * Default value is 1.0. You have to enable cross fade before using it.
+         * Cross Fading is currently only available if OpenGL is used.
+         * @see enableCrossFade
+         * @see isCrossFade
+         * @see crossFadeProgress
+         * @since 4.6
+         **/
+        void setCrossFadeProgress( qreal progress );
+        /**
+         * @returns The current progress for cross fading
+         * @see setCrossFadeProgress
+         * @see enableCrossFade
+         * @see isCrossFade
+         * @since 4.6
+         **/
+        qreal crossFadeProgress() const;
 
     private:
-        Q_DISABLE_COPY( EffectFrame ) // As we need to use Qt slots we cannot copy this class
-
-        void autoResize(); // Auto-resize if not a static size
-        void updateTexture(); // Update OpenGL styled frame texture
-        void updateTextTexture(); // Update OpenGL text texture
-        void updatePicture(); // Update XRender styled frame picture
-        void updateTextPicture(); // Update XRender text picture
-
-        Style m_style;
-        Plasma::FrameSvg m_frame;
-        GLTexture* m_texture;
-        GLTexture* m_textTexture;
-        XRenderPicture* m_picture;
-        XRenderPicture* m_textPicture;
-
-        // Position
-        bool m_static;
-        QPoint m_point;
-        Qt::Alignment m_alignment;
-        QRect m_geometry;
-
-        // Contents
-        QString m_text;
-        QFont m_font;
-        QPixmap m_icon;
-        QSize m_iconSize;
-
-        static GLTexture* m_unstyledTexture;
-        static void updateUnstyledTexture(); // Update OpenGL unstyled frame texture
+        EffectFramePrivate* const d;
     };
 
 /**
@@ -1746,27 +1829,6 @@ class KWIN_EXPORT EffectFrame : public QObject
  **/
 extern KWIN_EXPORT EffectsHandler* effects;
 
-/***************************************************************
- EffectsHandler
-***************************************************************/
-
-inline
-bool EffectsHandler::paintText( const QString& text, const QPoint& center, int maxwidth,
-        const QColor& color, const QFont& font )
-{
-    return paintText( text, QRect( center.x() - maxwidth / 2, center.y() - 5000, maxwidth, 10000 ),
-        color, font, Qt::AlignCenter );
-}
-
-inline
-bool EffectsHandler::paintTextWithBackground( const QString& text, const QPoint& center, int maxwidth,
-        const QColor& color, const QColor& bgcolor, const QFont& font )
-{
-    return paintTextWithBackground( text,
-        QRect( center.x() - maxwidth / 2, center.y() - 5000, maxwidth, 10000 ),
-        color, bgcolor, font, Qt::AlignCenter );
-}
-
 /***************************************************************
  WindowVertex
 ***************************************************************/
