@@ -39,14 +39,21 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <kxerrorhandler.h>
 #include <kdefakes.h>
 #include <QtDBus/QtDBus>
+#include <stdlib.h>
+#include <QMessageBox>
+#include <QEvent>
+#include "scripting/scripting.h"
 
 #include <kdialog.h>
 #include <kstandarddirs.h>
 #include <kdebug.h>
+#include <kde_file.h>
 #include <QLabel>
-#include <QComboBox>
+#include <KComboBox>
 #include <QVBoxLayout>
 
+#include <ksmserver_interface.h>
+
 #include "atoms.h"
 #include "options.h"
 #include "sm.h"
@@ -77,6 +84,9 @@ bool initting = false;
  */
 static bool kwin_sync = false;
 
+// errorMessage is only used ifndef NDEBUG, and only in one place.
+// it might be worth reevaluating why this is used? I don't know.
+#ifndef NDEBUG
 /**
  * Outputs: "Error: <error> (<value>), Request: <request>(<value>), Resource: <value>"
  */
@@ -161,9 +171,11 @@ static QByteArray errorMessage( const XErrorEvent& event, Display* dpy )
         }
     return ret;
     }
+#endif
 
 static int x11ErrorHandler( Display* d, XErrorEvent* e )
     {
+    Q_UNUSED( d );
     bool ignore_badwindow = true; // Might be temporary
 
     if( initting && ( e->request_code == X_ChangeWindowAttributes || e->request_code == X_GrabKey ) &&
@@ -203,7 +215,7 @@ class AlternativeWMDialog : public KDialog
                 "You can select another window manager to run:" );
             QLabel* textLabel = new QLabel( text, mainWidget );
             layout->addWidget( textLabel );
-            wmList = new QComboBox( mainWidget );
+            wmList = new KComboBox( mainWidget );
             wmList->setEditable( true );
             layout->addWidget( wmList );
 
@@ -228,7 +240,7 @@ class AlternativeWMDialog : public KDialog
             { return wmList->currentText(); }
 
     private:
-        QComboBox* wmList;
+        KComboBox* wmList;
 };
 
 int Application::crashes = 0;
@@ -248,9 +260,7 @@ Application::Application()
     KSharedConfig::Ptr config = KGlobal::config();
     if( !config->isImmutable() && args->isSet( "lock" ))
         {
-#ifdef __GNUC__
-#warning this shouldn not be necessary
-#endif
+        // TODO: This shouldn't be necessary
         //config->setReadOnly( true );
         config->reparseConfiguration();
         }
@@ -415,7 +425,7 @@ KDE_EXPORT int kdemain( int argc, char * argv[] )
         { // We only do the multihead fork if we are not restored by the session
           // manager, since the session manager will register multiple kwins,
           // one for each screen...
-        QByteArray multiHead = getenv( "KDE_MULTIHEAD" );
+        QByteArray multiHead = qgetenv( "KDE_MULTIHEAD" );
         if( multiHead.toLower() == "true" )
             {
             Display* dpy = XOpenDisplay( NULL );
@@ -475,7 +485,8 @@ KDE_EXPORT int kdemain( int argc, char * argv[] )
     aboutData.addAuthor( ki18n( "Matthias Ettrich" ),KLocalizedString(), "ettrich@kde.org" );
     aboutData.addAuthor( ki18n( "Cristian Tibirna" ),KLocalizedString(), "tibirna@kde.org" );
     aboutData.addAuthor( ki18n( "Daniel M. Duley" ),KLocalizedString(), "mosfet@kde.org" );
-    aboutData.addAuthor( ki18n( "Luboš Luňák" ), ki18n( "Maintainer" ), "l.lunak@kde.org" );
+    aboutData.addAuthor( ki18n( "Luboš Luňák" ), KLocalizedString(), "l.lunak@kde.org" );
+    aboutData.addAuthor( ki18n( "Martin Gräßlin" ), ki18n( "Maintainer" ), "kde@martin-graesslin.com" );
 
     KCmdLineArgs::init( argc, argv, &aboutData );
 
@@ -483,29 +494,35 @@ KDE_EXPORT int kdemain( int argc, char * argv[] )
     args.add( "lock", ki18n( "Disable configuration options" ));
     args.add( "replace", ki18n( "Replace already-running ICCCM2.0-compliant window manager" ));
     args.add( "crashes <n>", ki18n( "Indicate that KWin has recently crashed n times" ));
+    args.add( "noscript", ki18n( "Load the script testing dialog" ));
     KCmdLineArgs::addCmdLineOptions( args );
 
-    if( signal( SIGTERM, KWin::sighandler ) == SIG_IGN )
-        signal( SIGTERM, SIG_IGN );
-    if( signal( SIGINT, KWin::sighandler ) == SIG_IGN )
-        signal( SIGINT, SIG_IGN );
-    if( signal( SIGHUP, KWin::sighandler ) == SIG_IGN )
-        signal( SIGHUP, SIG_IGN );
-
-    // HACK: This is needed for AIGLX
-    if( qstrcmp( getenv( "KWIN_DIRECT_GL" ), "1" ) != 0 )
-        setenv( "LIBGL_ALWAYS_INDIRECT","1", true );
+    if( KDE_signal( SIGTERM, KWin::sighandler ) == SIG_IGN )
+        KDE_signal( SIGTERM, SIG_IGN );
+    if( KDE_signal( SIGINT, KWin::sighandler ) == SIG_IGN )
+        KDE_signal( SIGINT, SIG_IGN );
+    if( KDE_signal( SIGHUP, KWin::sighandler ) == SIG_IGN )
+        KDE_signal( SIGHUP, SIG_IGN );
 
     // HACK: this is needed to work around a Qt4.4.0RC1 bug (#157659)
     setenv( "QT_SLOW_TOPLEVEL_RESIZE", "1", true );
 
+    // Disable the glib event loop integration, since it seems to be responsible
+    // for several bug reports about high CPU usage (bug #239963)
+    setenv( "QT_NO_GLIB", "1", true );
+
+    org::kde::KSMServerInterface ksmserver( "org.kde.ksmserver", "/KSMServer", QDBusConnection::sessionBus());
+    ksmserver.suspendStartup( "kwin" );
     KWin::Application a;
+    KWin::Scripting scripting;
+    
+    ksmserver.resumeStartup( "kwin" );
     KWin::SessionManager weAreIndeed;
     KWin::SessionSaveDoneHelper helper;
     KGlobal::locale()->insertCatalog( "kwin_effects" );
 
     // Announce when KWIN_DIRECT_GL is set for above HACK
-    if( qstrcmp( getenv( "KWIN_DIRECT_GL" ), "1" ) == 0 )
+    if( qstrcmp( qgetenv( "KWIN_DIRECT_GL" ), "1" ) == 0 )
         kDebug( 1212 ) << "KWIN_DIRECT_GL set, not forcing LIBGL_ALWAYS_INDIRECT=1";
 
     fcntl( XConnectionNumber( KWin::display() ), F_SETFD, 1 );
@@ -519,7 +536,10 @@ KDE_EXPORT int kdemain( int argc, char * argv[] )
     QDBusConnection::sessionBus().interface()->registerService(
         appname, QDBusConnectionInterface::DontQueueService );
 
+    KCmdLineArgs* sargs = KCmdLineArgs::parsedArgs();
+    scripting.start();
+
     return a.exec();
-    }
+}
 
 #include "main.moc"
