@@ -61,6 +61,7 @@ class WindowRules
         QSize checkMaxSize( QSize s ) const;
         int checkOpacityActive(int s) const;
         int checkOpacityInactive(int s) const;
+        int checkTilingOption( int s ) const;
         bool checkIgnoreGeometry( bool ignore ) const;
         int checkDesktop( int desktop, bool init = false ) const;
         NET::WindowType checkType( NET::WindowType type ) const;
@@ -69,6 +70,7 @@ class WindowRules
         ShadeMode checkShade( ShadeMode shade, bool init = false ) const;
         bool checkSkipTaskbar( bool skip, bool init = false ) const;
         bool checkSkipPager( bool skip, bool init = false ) const;
+        bool checkSkipSwitcher( bool skip, bool init = false ) const;
         bool checkKeepAbove( bool above, bool init = false ) const;
         bool checkKeepBelow( bool below, bool init = false ) const;
         bool checkFullScreen( bool fs, bool init = false ) const;
@@ -115,6 +117,7 @@ class Rules
         bool applyMaxSize( QSize& s ) const;
         bool applyOpacityActive(int& s) const;
         bool applyOpacityInactive(int& s) const;
+        bool applyTilingOption( int& s ) const;
         bool applyIgnoreGeometry( bool& ignore ) const;
         bool applyDesktop( int& desktop, bool init ) const;
         bool applyType( NET::WindowType& type ) const;
@@ -124,6 +127,7 @@ class Rules
         bool applyShade( ShadeMode& shade, bool init ) const;
         bool applySkipTaskbar( bool& skip, bool init ) const;
         bool applySkipPager( bool& skip, bool init ) const;
+        bool applySkipSwitcher( bool& skip, bool init ) const;
         bool applyKeepAbove( bool& above, bool init ) const;
         bool applyKeepBelow( bool& below, bool init ) const;
         bool applyFullScreen( bool& fs, bool init ) const;
@@ -214,6 +218,8 @@ class Rules
         ForceRule opacityactiverule;
         int opacityinactive;
         ForceRule opacityinactiverule;
+        int tilingoption;
+        ForceRule tilingoptionrule;
         bool ignoreposition;
         ForceRule ignorepositionrule;
         int desktop;
@@ -232,6 +238,8 @@ class Rules
         SetRule skiptaskbarrule;
         bool skippager;
         SetRule skippagerrule;
+        bool skipswitcher;
+        SetRule skipswitcherrule;
         bool above;
         SetRule aboverule;
         bool below;
@@ -260,7 +268,7 @@ class Rules
         SetRule shortcutrule;
         bool disableglobalshortcuts;
         ForceRule disableglobalshortcutsrule;
-        friend kdbgstream& operator<<( kdbgstream& stream, const Rules* );
+        friend QDebug& operator<<( QDebug& stream, const Rules* );
     };
 
 #ifndef KCMRULES
@@ -321,7 +329,7 @@ void WindowRules::remove( Rules* rule )
 
 #endif
 
-kdbgstream& operator<<( kdbgstream& stream, const Rules* );
+QDebug& operator<<( QDebug& stream, const Rules* );
 
 } // namespace
 
