@@ -57,7 +57,7 @@ Toplevel::~Toplevel()
     delete info;
     }
 
-kdbgstream& operator<<( kdbgstream& stream, const Toplevel* cl )
+QDebug& operator<<( QDebug& stream, const Toplevel* cl )
     {
     if( cl == NULL )
         return stream << "\'NULL\'";
@@ -65,7 +65,7 @@ kdbgstream& operator<<( kdbgstream& stream, const Toplevel* cl )
     return stream;
     }
 
-kdbgstream& operator<<( kdbgstream& stream, const ToplevelList& list )
+QDebug& operator<<( QDebug& stream, const ToplevelList& list )
     {
     stream << "LIST:(";
     bool first = true;
@@ -82,7 +82,7 @@ kdbgstream& operator<<( kdbgstream& stream, const ToplevelList& list )
     return stream;
     }
 
-kdbgstream& operator<<( kdbgstream& stream, const ConstToplevelList& list )
+QDebug& operator<<( QDebug& stream, const ConstToplevelList& list )
     {
     stream << "LIST:(";
     bool first = true;
@@ -142,6 +142,11 @@ void Toplevel::disownDataPassedToDeleted()
     info = NULL;
     }
 
+QRect Toplevel::visibleRect() const
+    {
+    return geometry();
+    }
+
 NET::WindowType Toplevel::windowType( bool direct, int supported_types ) const
     {
     if( supported_types == 0 )
@@ -151,11 +156,7 @@ NET::WindowType Toplevel::windowType( bool direct, int supported_types ) const
     if( direct )
         return wt;
     const Client* cl = dynamic_cast< const Client* >( this );
-#ifdef __GNUC__
-#warning TODO
-#endif
-//    NET::WindowType wt2 = rules()->checkType( wt );
-    NET::WindowType wt2 = wt;
+    NET::WindowType wt2 = cl ? cl->rules()->checkType( wt ) : wt;
     if( wt != wt2 )
         {
         wt = wt2;
