@@ -25,12 +25,12 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #ifndef TASKMANAGER_H
 #define TASKMANAGER_H
 
-#include <QtCore/QHash>
-#include <QtCore/QSet>
-#include <QtCore/QVector>
+#include <QHash>
+#include <QSet>
+#include <QVector>
 
-#include <KDE/KSharedPtr>
-#include <KDE/KWindowSystem>
+#include <KSharedPtr>
+#include <KWindowSystem>
 
 struct QUuid;
 
@@ -57,6 +57,7 @@ enum TaskChange { TaskUnchanged = 0,
                   TransientsChanged = 512,
                   IconChanged = 1024,
                   ColorChanged = 2048,
+                  ActivitiesChanged = 4096,
                   EverythingChanged = 0xffff
                 };
 Q_DECLARE_FLAGS(TaskChanges, TaskChange)
@@ -83,6 +84,7 @@ class TASKMANAGER_EXPORT TaskManager : public QObject
     Q_OBJECT
     Q_PROPERTY( int currentDesktop READ currentDesktop )
     Q_PROPERTY( int numberOfDesktops READ numberOfDesktops )
+    Q_PROPERTY( QString currentActivity READ currentActivity )
 
 public:
     static TaskManager* self();
@@ -125,6 +127,11 @@ public:
      */
     int currentDesktop() const;
 
+    /**
+     * Returns the number of the current desktop.
+     */
+    QString currentActivity() const;
+
     /**
      * Returns true if the specified task is on top.
      */
@@ -175,6 +182,11 @@ Q_SIGNALS:
      */
     void desktopChanged(int desktop);
 
+    /**
+     * Emitted when the current activity changes.
+     */
+    void activityChanged(const QString &activity);
+
     /**
      * Emitted when a window changes desktop.
      */
@@ -193,6 +205,8 @@ protected Q_SLOTS:
     //* @internal
     void currentDesktopChanged(int);
     //* @internal
+    void currentActivityChanged(const QString&);
+    //* @internal
     void killStartup( const KStartupInfoId& );
     //* @internal
     void killStartup(StartupPtr);
