@@ -30,6 +30,7 @@
 #include <QtGui/QStandardItem>
 #include <QtGui/QStyleOptionMenuItem>
 #include <QtGui/QPainter>
+#include <QtGui/QToolTip>
 
 // KDE
 #include <KDebug>
@@ -162,17 +163,20 @@ QAction *MenuView::createLeafAction(const QModelIndex &index, QObject *parent)
 void MenuView::updateAction(QAbstractItemModel *model, QAction *action, const QModelIndex& index)
 {
     bool isSeparator = index.data(Kickoff::SeparatorRole).value<bool>();
-    QString text = index.data(Qt::DisplayRole).value<QString>().replace('&', "&&"); // describing text, e.g. "Spreadsheet" or "Rekall" (right, sometimes the text is also used for the generic app-name)
-    QString name = index.data(Kickoff::SubTitleRole).value<QString>().replace('&', "&&"); // the generic name, e.g. "kspread" or "OpenOffice.org Spreadsheet" or just "" (right, it's a mess too)
+    QString name = index.data(Qt::DisplayRole).value<QString>().replace('&', "&&"); // the generic name, e.g. "kspread" or "OpenOffice.org Spreadsheet" or just "" (right, it's a mess too)
+    QString text = index.data(Kickoff::SubTitleRole).value<QString>().replace('&', "&&"); // describing text, e.g. "Spreadsheet" or "Rekall" (right, sometimes the text is also used for the generic app-name)
     if (action->menu() != 0) { // if it is an item with sub-menuitems, we probably like to thread them another way...
-        action->setText(text);
+        action->setText(name);
     } else {
         switch (d->formattype) {
         case Name: {
+
             action->setText(name.isEmpty() ? text : name);
+            action->setToolTip(text);
         } break;
         case Description: {
             action->setText(name.contains(text, Qt::CaseInsensitive) ? name : text);
+            action->setToolTip(name);
         } break;
         case NameDescription: // fall through
         case NameDashDescription: // fall through
@@ -270,6 +274,30 @@ bool MenuView::eventFilter(QObject *watched, QEvent *event)
     case QEvent::Hide: {
         emit afterBeingHidden();
     } break;
+
+    case QEvent::ToolTip: {
+        bool hide = true;
+
+        if ((d->formattype == Name) || (d->formattype == Description)) {
+            QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
+            QMenu *watchedMenu = qobject_cast<QMenu*>(watched);
+
+            if (watchedMenu && watchedMenu->activeAction()) {
+                QString toolTip = watchedMenu->activeAction()->toolTip();
+
+                if ((toolTip != watchedMenu->activeAction()->text()) && (watchedMenu->activeAction()->menu() == 0)) {
+                QToolTip::showText(helpEvent->globalPos(), toolTip);
+                hide = false ;
+		}
+	    }
+	} 
+
+   if (hide) {
+         QToolTip::hideText();
+         event->ignore();
+   }
+    } break;
+    
     default: break;
     }
 
