@@ -19,14 +19,13 @@
 #include "plasma-desktop-runner.h"
 
 #include <QDBusConnection>
+#include <QDBusServiceWatcher>
 #include <QDBusConnectionInterface>
-#include <QDBusInterface>
 
 #include <KDebug>
 #include <KIcon>
 #include <KLocale>
 #include <KRun>
-#include <KToolInvocation>
 
 #include <plasma/theme.h>
 
@@ -37,13 +36,14 @@ PlasmaDesktopRunner::PlasmaDesktopRunner(QObject *parent, const QVariantList &ar
       m_desktopConsoleKeyword(i18nc("Note this is a KRunner keyword", "desktop console")),
       m_enabled(false)
 {
-    setObjectName("Plasma-Desktop");
+    setObjectName( QLatin1String("Plasma-Desktop" ));
     setIgnoredTypes(Plasma::RunnerContext::FileSystem |
                     Plasma::RunnerContext::NetworkLocation |
                     Plasma::RunnerContext::Help);
-
-    QObject::connect(QDBusConnection::sessionBus().interface(), SIGNAL(serviceOwnerChanged(QString,QString,QString)),
-                     this, SLOT(checkAvailability(QString,QString,QString)));
+    QDBusServiceWatcher *watcher = new QDBusServiceWatcher(s_plasmaService, QDBusConnection::sessionBus(),
+                                                           QDBusServiceWatcher::WatchForOwnerChange, this);
+    connect(watcher, SIGNAL(serviceOwnerChanged(QString,QString,QString)),
+            this, SLOT(checkAvailability(QString,QString,QString)));
     checkAvailability(QString(), QString(), QString());
 }
 
@@ -95,11 +95,8 @@ void PlasmaDesktopRunner::checkAvailability(const QString &name, const QString &
     bool enabled = false;
     if (name.isEmpty()) {
         enabled = QDBusConnection::sessionBus().interface()->isServiceRegistered(s_plasmaService).value();
-    } else if (name == s_plasmaService) {
-        enabled = !newOwner.isEmpty();
     } else {
-        // it's not something we're interested in
-        return;
+        enabled = !newOwner.isEmpty();
     }
 
     if (m_enabled != enabled) {
