@@ -33,7 +33,6 @@
 #include <KStandardDirs>
 #include <KDesktopFile>
 #include <KGlobalSettings>
-#include <kcapacitybar.h>
 #include <kdesktopfileactions.h>
 
 //Plasma
@@ -42,6 +41,7 @@
 #include <Plasma/BusyWidget>
 #include <Plasma/ItemBackground>
 #include <Plasma/Label>
+#include <Plasma/Meter>
 #include <Plasma/Animator>
 #include <Plasma/Animation>
 
@@ -50,12 +50,13 @@
 
 using namespace Notifier;
 
-DeviceItem::DeviceItem(const QString &udi, QGraphicsWidget *parent)
+DeviceItem::DeviceItem(const QString &udi, bool unpluggable, QGraphicsWidget *parent)
     : QGraphicsWidget(parent),
       m_udi(udi),
       m_hovered(false),
       m_mounted(false),
       m_safelyRemovable(true),
+      m_unpluggable(unpluggable),
       m_state(DeviceItem::Idle),
       m_labelFade(0),
       m_barFade(0)
@@ -107,16 +108,16 @@ DeviceItem::DeviceItem(const QString &udi, QGraphicsWidget *parent)
     m_descriptionLabel->setOpacity(0);
     updateColors();
 
-    KCapacityBar *capacityBarWidget = new KCapacityBar(KCapacityBar::DrawTextInline);
-    m_capacityBar = new QGraphicsProxyWidget(this);
-    m_capacityBar->setWidget(capacityBarWidget);
-    capacityBarWidget->setAttribute(Qt::WA_TranslucentBackground);
-    capacityBarWidget->setContinuous(true);
-    m_capacityBar->setAcceptHoverEvents(false);
-    m_capacityBar->setOpacity(0);
+
+    m_freeSpaceBar = new Plasma::Meter();
+    m_freeSpaceBar->setMeterType(Plasma::Meter::BarMeterHorizontal);
+    m_freeSpaceBar->setLabelAlignment(0, Qt::AlignCenter);
+    m_freeSpaceBar->setOpacity(0);
+    m_freeSpaceBar->setMaximumHeight(12);
+
     info_layout->addItem(m_nameLabel);
     info_layout->addItem(m_descriptionLabel);
-    info_layout->addItem(m_capacityBar);
+    info_layout->addItem(m_freeSpaceBar);
 
     m_leftActionIcon = new Plasma::IconWidget(this);
     m_leftActionIcon->setMaximumSize(m_leftActionIcon->sizeFromIconSize(LEFTACTION_SIZE));
@@ -279,21 +280,38 @@ void DeviceItem::setSafelyRemovable(const bool safe)
     updateTooltip();
 }
 
+bool DeviceItem::unpluggable()
+{
+    return m_unpluggable;
+}
+
 void DeviceItem::updateTooltip()
 {
     if (m_mounted) {
         if (data(NotifierDialog::IsOpticalMedia).toBool()) {
             m_leftActionIcon->setToolTip(i18n("Click to eject this disc."));
         } else {
-            m_leftActionIcon->setToolTip(i18n("Click to safely remove this device."));
+            if (unpluggable()) {
+                m_leftActionIcon->setToolTip(i18n("Click to safely remove this device."));
+            } else {
+                m_leftActionIcon->setToolTip(i18n("Click to unmount this device."));
+            }
+        }
+        if (unpluggable()) {
+            m_deviceIcon->setToolTip(i18n("It is currently <b>not safe</b> to remove this device: applications may be accessing it. Click the eject button to safely remove this device."));
+        } else {
+            m_deviceIcon->setToolTip(i18n("This device is currently accessible."));
         }
-        m_deviceIcon->setToolTip(i18n("It is currently <b>not safe</b> to remove this device: applications may be accessing it. Click the eject button to safely remove this device."));
     } else {
         m_leftActionIcon->setToolTip(i18n("Click to access this device from other applications."));
-        if (safelyRemovable()) {
-            m_deviceIcon->setToolTip(i18n("It is currently safe to remove this device."));
+        if (unpluggable()) {
+            if (safelyRemovable()) {
+                m_deviceIcon->setToolTip(i18n("It is currently safe to remove this device."));
+            } else {
+                m_deviceIcon->setToolTip(i18n("It is currently <b>not safe</b> to remove this device: applications may be accessing other volumes on this device. Click the eject button on these other volumes to safely remove this device."));
+            }
         } else {
-            m_deviceIcon->setToolTip(i18n("It is currently <b>not safe</b> to remove this device: applications may be accessing other volumes on this device. Click the eject button on these other volumes to safely remove this device."));
+            m_deviceIcon->setToolTip(i18n("This device is currently not accessible."));
         }
     }
 }
@@ -318,9 +336,9 @@ void DeviceItem::setMounted(const bool mounted)
         }
     }
 
-    const bool barVisible = m_capacityBar->isVisible();
-    m_capacityBar->setVisible(m_mounted && allowsCapacityBar());
-    if (!barVisible && m_capacityBar->isVisible()) {
+    const bool barVisible = m_freeSpaceBar->isVisible();
+    m_freeSpaceBar->setVisible(m_mounted && allowsCapacityBar());
+    if (!barVisible && m_freeSpaceBar->isVisible()) {
         // work around for a QGraphicsLayout bug when used with proxy widgets
         m_mainLayout->invalidate();
     }
@@ -361,7 +379,7 @@ void DeviceItem::setHovered(const bool hovered)
             m_barFade = Plasma::Animator::create(Plasma::Animator::FadeAnimation, this);
 
             m_labelFade->setTargetWidget(m_descriptionLabel);
-            m_barFade->setTargetWidget(m_capacityBar);
+            m_barFade->setTargetWidget(m_freeSpaceBar);
 
             m_labelFade->setProperty("targetOpacity", 0);
             m_barFade->setProperty("targetOpacity", 0);
@@ -379,15 +397,15 @@ void DeviceItem::setHovered(const bool hovered)
 void DeviceItem::setHoverDisplayOpacity(qreal opacity)
 {
     m_descriptionLabel->setOpacity(opacity);
-    m_capacityBar->setOpacity(opacity);
+    m_freeSpaceBar->setOpacity(opacity);
 }
 
 void DeviceItem::setFreeSpace(qulonglong freeSpace, qulonglong size)
 {
     qulonglong usedSpace = size - freeSpace;
-    KCapacityBar *capacityBarWidget = static_cast<KCapacityBar*>(m_capacityBar->widget());
-    capacityBarWidget->setText(i18nc("@info:status Free disk space", "%1 free", KGlobal::locale()->formatByteSize(freeSpace)));
-    capacityBarWidget->setValue(size > 0 ? (usedSpace * 100) / size : 0);
+
+    m_freeSpaceBar->setToolTip(i18nc("@info:status Free disk space", "%1 free", KGlobal::locale()->formatByteSize(freeSpace)));
+    m_freeSpaceBar->setValue(size > 0 ? (usedSpace * 100) / size : 0);
 }
 
 void DeviceItem::leftActionClicked()
