@@ -32,17 +32,53 @@
 ///Ui includes
 #include "ui_configurationpage.h"
 
-namespace Notifier
-{
-    class NotifierDialog;
-}
-
 class KCModuleProxy;
 
+namespace Notifier
+{
+
+class NotifierDialog;
+
+class HotplugDataConsumer : public QObject
+{
+    Q_OBJECT
+public:
+    HotplugDataConsumer(NotifierDialog *parent);
+
+protected Q_SLOTS:
+        /**
+     * slot called when a source of the hotplug engine is updated
+     * @param udi the udi of the source
+     * @param data the data of the source
+     **/
+    void dataUpdated(const QString &udi, Plasma::DataEngine::Data data);
+
+private:
+    NotifierDialog * const m_dialog;
+};
+
+class DeviceDataConsumer : public QObject
+{
+    Q_OBJECT
+public:
+    DeviceDataConsumer(NotifierDialog *parent);
+
+protected Q_SLOTS:
+        /**
+     * slot called when a source of the hotplug engine is updated
+     * @param udi the udi of the source
+     * @param data the data of the source
+     **/
+    void dataUpdated(const QString &udi, Plasma::DataEngine::Data data);
+
+private:
+    NotifierDialog * const m_dialog;
+};
+
 /**
-* @short Applet used to display devices
-*
-*/
+ * @short Applet used to display devices
+ *
+ */
 class DeviceNotifier : public Plasma::PopupApplet
 {
     Q_OBJECT
@@ -55,50 +91,64 @@ class DeviceNotifier : public Plasma::PopupApplet
         };
 
         /**
-        * Constructor of the applet
-        * @param parent the parent of this object
-        **/
+         * Constructor of the applet
+         * @param parent the parent of this object
+         **/
         DeviceNotifier(QObject *parent, const QVariantList &args);
 
         /**
-        * Default destructor
-        **/
+         * Default destructor
+         **/
         ~DeviceNotifier();
 
         /**
-        * initialize the applet (called by plasma automatically)
-        **/
+         * initialize the applet (called by plasma automatically)
+         **/
         void init();
 
         /**
-        * Used to know it there are hidden devices
-        * @return true if there are hidden device
-        **/	
+         * Used to know it there are hidden devices
+         * @return true if there are hidden device
+         **/
         bool areThereHiddenDevices();
 
         /**
-        *  allow to change the icon of the notifier if this applet is in icon mode
-        *  @param name icon name
-        *  @param timeout if not 0, time to wait before resetting the icon (in msecs)
-        **/
+         *  allow to change the icon of the notifier if this applet is in icon mode
+         *  @param name icon name
+         *  @param timeout if not 0, time to wait before resetting the icon (in msecs)
+         **/
         void changeNotifierIcon(const QString &name = QString(), uint timeout = 0);
 
         /**
-        * The graphics widget that displays the list of devices.
-        */
+         * The graphics widget that displays the list of devices.
+         */
         QGraphicsWidget *graphicsWidget();
 
+	/**
+	 * Return true if the applet has been opened for internal reasons (i.e. has been shown
+	 * with no user interaction);
+	 **/
+	bool poppedUpInternally();
+
+	/**
+	 * Force to keep the applet open until the user closes it manually
+	 */
+	void keepPopupOpen();
+
         QList<QAction *> contextualActions();
 
+        static const int LONG_NOTIFICATION_TIMEOUT = 7500;
+        static const int SHORT_NOTIFICATION_TIMEOUT = 2500;
+
     protected:
         /**
-        * Reimplemented from Plasma::Applet
-        **/
+         * Reimplemented from Plasma::Applet
+         **/
         void contextMenuEvent(QGraphicsSceneContextMenuEvent *event);
 
         /**
-        * Reimplemented from Plasma::Applet
-        **/
+         * Reimplemented from Plasma::Applet
+         **/
         void createConfigurationInterface(KConfigDialog *parent);
 
         /**
@@ -111,7 +161,7 @@ class DeviceNotifier : public Plasma::PopupApplet
         * Reimplemented from Plasma::Applet
         **/
         void configChanged();
-        
+
         /**
         * @internal Sets the tooltip content properly before showing.
         */
@@ -138,8 +188,10 @@ class DeviceNotifier : public Plasma::PopupApplet
         /**
         * Shows a message
         * @param message the text of the message
+        * @param details details of the notification
+        * @param udi the udi of the device
         **/
-        void showErrorMessage(const QString &message, const QString &details, const QString &udi);
+        void showNotification(const QString &message, const QString &details, const QString &udi);
 
     protected slots:
         /**
@@ -154,13 +206,6 @@ class DeviceNotifier : public Plasma::PopupApplet
         **/
         void onSourceRemoved(const QString &udi);
 
-        /**
-        * slot called when a source of the hotplug engine is updated
-        * @param udi the udi of the source
-        * @param data the data of the source
-        **/
-        void dataUpdated(const QString &udi, Plasma::DataEngine::Data data);
-
         /**
         * Reimplemented from Plasma::Applet
         **/
@@ -200,8 +245,12 @@ class DeviceNotifier : public Plasma::PopupApplet
          */
         void removeLastDeviceNotification(const QString &udi);
 
+        // Data consumers that relay information to the main applet
+        HotplugDataConsumer *m_hotplugDataConsumer;
+        DeviceDataConsumer *m_deviceDataConsumer;
+
         ///the engine used to get hot plug devices
-        Plasma::DataEngine *m_solidEngine;
+        Plasma::DataEngine *m_hotplugEngine;
 
         ///The engine used to manage devices in the applet (unmount,...)
         Plasma::DataEngine *m_solidDeviceEngine;
@@ -251,9 +300,16 @@ class DeviceNotifier : public Plasma::PopupApplet
         ///if true the applet will check if the removed devices were hidded
         bool m_checkHiddenDevices : 1;
 
+        ///if true we are triggering the popup internally
+        bool m_triggeringPopupInternally : 1;
+
+	///if true the applet popped up without user interaction (e.g. new device inserted)
+	bool m_poppedUpInternally : 1;
+
         ///embedded KCM modules in the configuration dialog
         KCModuleProxy *m_autoMountingWidget;
         KCModuleProxy *m_deviceActionsWidget;
 };
 
+}
 #endif
