@@ -23,6 +23,7 @@
 #include "dbusnotificationprotocol.h"
 
 #include <KConfigGroup>
+#include <KDebug>
 #include <KIcon>
 
 #include <Plasma/DataEngineManager>
@@ -94,6 +95,7 @@ void DBusNotificationProtocol::dataUpdated(const QString &source, const Plasma::
     notification->setSummary(data.value("summary").toString());
     notification->setMessage(data.value("body").toString());
     notification->setTimeout(data.value("expireTimeout").toInt());
+    notification->setUrgency(data.value("urgency").toInt());
 
     if (data.contains("image")) {
         QImage image = qvariant_cast<QImage>(data.value("image"));
@@ -168,7 +170,7 @@ void DBusNotificationProtocol::hideNotification(const QString &source)
 void DBusNotificationProtocol::removeNotification(const QString &source)
 {
     if (m_notifications.contains(source)) {
-        m_notifications.take(source)->deleteLater();
+        m_notifications.take(source)->destroy();
     }
 }
 
