@@ -190,10 +190,12 @@ void Calendar::Private::updateItem( const Akonadi::Item &item, UpdateMode mode )
            << "alreadyExisted=" << alreadyExisted
            << "; mode = " << mode
            << "; calendar = " << q;
-  Q_ASSERT( mode == DontCare || alreadyExisted == ( mode == AssertExists ) );
+  //Q_ASSERT( mode == DontCare || alreadyExisted == ( mode == AssertExists ) );
 
   const KCalCore::Incidence::Ptr incidence = CalendarSupport::incidence( item );
-  Q_ASSERT( incidence );
+  if (!incidence) {
+      return;
+  }
 
   if ( alreadyExisted ) {
 
