@@ -41,7 +41,7 @@ SolidRunner::SolidRunner(QObject* parent, const QVariantList& args)
       m_deviceList()
 {
     Q_UNUSED(args)
-    setObjectName("Solid");
+    setObjectName( QLatin1String("Solid" ));
 
     m_engineManager = Plasma::DataEngineManager::self();
 
@@ -51,8 +51,13 @@ SolidRunner::SolidRunner(QObject* parent, const QVariantList& args)
                                    i18n("Lists all devices and allows them to be mounted, unmounted or ejected.")));
     addSyntax(Plasma::RunnerSyntax(i18nc("Note this is a KRunner keyword", "mount"),
                                    i18n("Lists all devices which can be mounted, and allows them to be mounted.")));
+    addSyntax(Plasma::RunnerSyntax(i18nc("Note this is a KRunner keyword", "unlock"),
+                                   i18n("Lists all encrypted devices which can be unlocked, and allows them to be unlocked.")));
     addSyntax(Plasma::RunnerSyntax(i18nc("Note this is a KRunner keyword", "unmount"),
                                    i18n("Lists all devices which can be unmounted, and allows them to be unmounted.")));
+    addSyntax(Plasma::RunnerSyntax(i18nc("Note this is a KRunner keyword", "lock"),
+                                   i18n("Lists all encrypted devices which can be locked, and allows them to be locked.")));
+
     addSyntax(Plasma::RunnerSyntax(i18nc("Note this is a KRunner keyword", "eject"),
                                    i18n("Lists all devices which can be ejected, and allows them to be ejected.")));
 
@@ -78,9 +83,9 @@ void SolidRunner::init()
 
 void SolidRunner::cleanActionsForDevice(DeviceWrapper * dev)
 {
-    QStringList actionIds = dev->actionIds();
+    const QStringList actionIds = dev->actionIds();
     if (!actionIds.isEmpty()) {
-        foreach (QString id, actionIds) {
+        foreach (const QString& id, actionIds) {
             removeAction(id);
         }
     }
@@ -95,7 +100,7 @@ QList<QAction*> SolidRunner::actionsForMatch(const Plasma::QueryMatch &match)
         QStringList actionIds = dev->actionIds();
         kDebug() << actionIds;
         if (!actionIds.isEmpty()) {
-            foreach (QString id, actionIds) {
+            foreach (const QString& id, actionIds) {
                 actions << action(id);
             }
         }
@@ -127,6 +132,9 @@ void SolidRunner::createOrUpdateMatches(const QStringList &udiList)
     QString deviceDescription;
     bool onlyMounted = false;
     bool onlyMountable = false;
+    bool onlyEncrypted = false;
+    bool onlyOptical = false;
+    bool forceEject = false;
     bool showDevices = false;
     if (keywords[0].startsWith(i18nc("Note this is a KRunner keyword", "device") , Qt::CaseInsensitive)) {
         showDevices = true;
@@ -142,6 +150,21 @@ void SolidRunner::createOrUpdateMatches(const QStringList &udiList)
             showDevices = true;
             onlyMounted = true;
             keywords.removeFirst();
+        } else if (keywords[0].startsWith(i18nc("Note this is a KRunner keyword", "eject") , Qt::CaseInsensitive)) {
+            showDevices = true;
+            onlyOptical = true;
+            forceEject = true;
+            keywords.removeFirst();
+        } else if (keywords[0].startsWith(i18nc("Note this is a KRunner keyword", "unlock") , Qt::CaseInsensitive)) {
+            showDevices = true;
+            onlyMountable = true;
+            onlyEncrypted = true;
+            keywords.removeFirst();
+        } else if (keywords[0].startsWith(i18nc("Note this is a KRunner keyword", "lock") , Qt::CaseInsensitive)) {
+            showDevices = true;
+            onlyMounted = true;
+            onlyEncrypted = true;
+            keywords.removeFirst();
         }
     }
 
@@ -149,13 +172,16 @@ void SolidRunner::createOrUpdateMatches(const QStringList &udiList)
         deviceDescription = keywords[0];
     }
 
-    foreach (QString udi,  udiList) {
+    foreach (const QString& udi,  udiList) {
         DeviceWrapper * dev = m_deviceList.value(udi);
         if ((deviceDescription.isEmpty() && showDevices) || dev->description().contains(deviceDescription, Qt::CaseInsensitive)) {
-            if ((onlyMounted && dev->isAccessible()) ||
-                (onlyMountable && dev->isStorageAccess() && !dev->isAccessible()) ||
-                (!onlyMounted && !onlyMountable)) {
-
+            // This is getting quite messy indeed
+            if (((!onlyEncrypted) || (onlyEncrypted && dev->isEncryptedContainer())) &&
+                ((!onlyOptical) || (onlyOptical && dev->isOpticalDisc())) &&
+                ((onlyMounted && dev->isAccessible()) ||
+                 (onlyMountable && dev->isStorageAccess() && !dev->isAccessible()) ||
+                 (!onlyMounted && !onlyMountable))) {
+                dev->setForceEject(forceEject);
                 Plasma::QueryMatch match = deviceMatch(dev);
                 if (dev->description().compare(deviceDescription, Qt::CaseInsensitive)) {
                     match.setType(Plasma::QueryMatch::ExactMatch);
