@@ -17,7 +17,6 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <KApplication>
 #include <KAboutData>
 #include <KCmdLineArgs>
 #include <KLocale>
@@ -27,12 +26,12 @@
 #include "plasmaapp.h"
 
 static const char description[] = I18N_NOOP( "The KDE workspace application optimized for Netbook devices." );
-static const char version[] = "0.1";
+static const char version[] = "0.2";
 
 extern "C"
 KDE_EXPORT int kdemain(int argc, char **argv)
 {
-    KAboutData aboutData("plasma-netbook", 0, ki18n("Plasma Netbook"),
+    KAboutData aboutData("plasma-netbook", 0, ki18n("Plasma Netbook Shell"),
                          version, ki18n(description), KAboutData::License_GPL,
                          ki18n("Copyright 2006-2009, The KDE Team"));
     aboutData.addAuthor(ki18n("Aaron J. Seigo"),
